Class: Google::Cloud::Dialogflow::CX::V3::ContinuousTestResult
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::CX::V3::ContinuousTestResult
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/cx/v3/environment.rb
Overview
Represents a result from running a test case in an agent environment.
Defined Under Namespace
Modules: AggregatedTestResult
Instance Attribute Summary collapse
-
#name ⇒ ::String
The resource name for the continuous test result.
-
#result ⇒ ::Google::Cloud::Dialogflow::CX::V3::ContinuousTestResult::AggregatedTestResult
The result of this continuous test run, i.e.
-
#run_time ⇒ ::Google::Protobuf::Timestamp
Time when the continuous testing run starts.
-
#test_case_results ⇒ ::Array<::String>
A list of individual test case results names in this continuous test run.
Instance Attribute Details
#name ⇒ ::String
Returns The resource name for the continuous test result. Format:
projects/<Project ID>/locations/<Location ID>/agents/<Agent
ID>/environments/<Environment
ID>/continuousTestResults/<ContinuousTestResult ID>.
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/environment.rb', line 236 class ContinuousTestResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The overall result for a continuous test run in an agent environment. module AggregatedTestResult # Not specified. Should never be used. AGGREGATED_TEST_RESULT_UNSPECIFIED = 0 # All the tests passed. PASSED = 1 # At least one test did not pass. FAILED = 2 end end |
#result ⇒ ::Google::Cloud::Dialogflow::CX::V3::ContinuousTestResult::AggregatedTestResult
Returns The result of this continuous test run, i.e. whether all the tests in this continuous test run pass or not.
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/environment.rb', line 236 class ContinuousTestResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The overall result for a continuous test run in an agent environment. module AggregatedTestResult # Not specified. Should never be used. AGGREGATED_TEST_RESULT_UNSPECIFIED = 0 # All the tests passed. PASSED = 1 # At least one test did not pass. FAILED = 2 end end |
#run_time ⇒ ::Google::Protobuf::Timestamp
Returns Time when the continuous testing run starts.
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/environment.rb', line 236 class ContinuousTestResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The overall result for a continuous test run in an agent environment. module AggregatedTestResult # Not specified. Should never be used. AGGREGATED_TEST_RESULT_UNSPECIFIED = 0 # All the tests passed. PASSED = 1 # At least one test did not pass. FAILED = 2 end end |
#test_case_results ⇒ ::Array<::String>
Returns A list of individual test case results names in this continuous test run.
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/environment.rb', line 236 class ContinuousTestResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The overall result for a continuous test run in an agent environment. module AggregatedTestResult # Not specified. Should never be used. AGGREGATED_TEST_RESULT_UNSPECIFIED = 0 # All the tests passed. PASSED = 1 # At least one test did not pass. FAILED = 2 end end |