Class: Google::Cloud::Dialogflow::CX::V3::DeleteToolRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/cx/v3/tool.rb

Overview

The request message for Tools.DeleteTool.

Instance Attribute Summary collapse

Instance Attribute Details

#force::Boolean

Returns This field has no effect for Tools not being used. For Tools that are used:

  • If force is set to false, an error will be returned with message indicating the referenced resources.
  • If force is set to true, Dialogflow will remove the tool, as well as any references to the tool.

Returns:

  • (::Boolean)

    This field has no effect for Tools not being used. For Tools that are used:

    • If force is set to false, an error will be returned with message indicating the referenced resources.
    • If force is set to true, Dialogflow will remove the tool, as well as any references to the tool.


114
115
116
117
# File 'proto_docs/google/cloud/dialogflow/cx/v3/tool.rb', line 114

class DeleteToolRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The name of the Tool to be deleted. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/tools/<ToolID>.

Returns:

  • (::String)

    Required. The name of the Tool to be deleted. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/tools/<ToolID>.



114
115
116
117
# File 'proto_docs/google/cloud/dialogflow/cx/v3/tool.rb', line 114

class DeleteToolRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end