Class: Google::Cloud::Dialogflow::CX::V3::DeleteToolVersionRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/cx/v3/tool.rb

Overview

The request message for Tools.DeleteToolVersion.

Instance Attribute Summary collapse

Instance Attribute Details

#force::Boolean

Returns Optional. This field has no effect for Tools not being used. For Tools that are used:

  • If force is set to false, an error will be returned with message indicating the referenced resources.
  • If force is set to true, Dialogflow will remove the tool, as well as any references to the tool.

Returns:

  • (::Boolean)

    Optional. This field has no effect for Tools not being used. For Tools that are used:

    • If force is set to false, an error will be returned with message indicating the referenced resources.
    • If force is set to true, Dialogflow will remove the tool, as well as any references to the tool.


535
536
537
538
# File 'proto_docs/google/cloud/dialogflow/cx/v3/tool.rb', line 535

class DeleteToolVersionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The name of the tool version to delete. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/tools/<ToolID>/versions/<VersionID>.

Returns:

  • (::String)

    Required. The name of the tool version to delete. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/tools/<ToolID>/versions/<VersionID>.



535
536
537
538
# File 'proto_docs/google/cloud/dialogflow/cx/v3/tool.rb', line 535

class DeleteToolVersionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end