Class: Google::Cloud::Dialogflow::CX::V3::Example

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/cx/v3/example.rb

Overview

Example represents a sample execution of the playbook in the conversation.

An example consists of a list of ordered actions performed by end user or Dialogflow agent according the playbook instructions to fulfill the task.

Instance Attribute Summary collapse

Instance Attribute Details

#actions::Array<::Google::Cloud::Dialogflow::CX::V3::Action>

Returns Required. The ordered list of actions performed by the end user and the Dialogflow agent.

Returns:



165
166
167
168
# File 'proto_docs/google/cloud/dialogflow/cx/v3/example.rb', line 165

class Example
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#conversation_state::Google::Cloud::Dialogflow::CX::V3::OutputState

Returns Required. Example's output state.

Returns:



165
166
167
168
# File 'proto_docs/google/cloud/dialogflow/cx/v3/example.rb', line 165

class Example
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The timestamp of initial example creation.

Returns:



165
166
167
168
# File 'proto_docs/google/cloud/dialogflow/cx/v3/example.rb', line 165

class Example
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#description::String

Returns Optional. The high level concise description of the example. The max number of characters is 200.

Returns:

  • (::String)

    Optional. The high level concise description of the example. The max number of characters is 200.



165
166
167
168
# File 'proto_docs/google/cloud/dialogflow/cx/v3/example.rb', line 165

class Example
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#display_name::String

Returns Required. The display name of the example.

Returns:

  • (::String)

    Required. The display name of the example.



165
166
167
168
# File 'proto_docs/google/cloud/dialogflow/cx/v3/example.rb', line 165

class Example
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#language_code::String

Returns Optional. The language code of the example. If not specified, the agent's default language is used. Note: languages must be enabled in the agent before they can be used. Note: example's language code is not currently used in dialogflow agents.

Returns:

  • (::String)

    Optional. The language code of the example. If not specified, the agent's default language is used. Note: languages must be enabled in the agent before they can be used. Note: example's language code is not currently used in dialogflow agents.



165
166
167
168
# File 'proto_docs/google/cloud/dialogflow/cx/v3/example.rb', line 165

class Example
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns The unique identifier of the playbook example. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>/examples/<ExampleID>.

Returns:

  • (::String)

    The unique identifier of the playbook example. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>/examples/<ExampleID>.



165
166
167
168
# File 'proto_docs/google/cloud/dialogflow/cx/v3/example.rb', line 165

class Example
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#playbook_input::Google::Cloud::Dialogflow::CX::V3::PlaybookInput

Returns Optional. The input to the playbook in the example.

Returns:



165
166
167
168
# File 'proto_docs/google/cloud/dialogflow/cx/v3/example.rb', line 165

class Example
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#playbook_output::Google::Cloud::Dialogflow::CX::V3::PlaybookOutput

Returns Optional. The output of the playbook in the example.

Returns:



165
166
167
168
# File 'proto_docs/google/cloud/dialogflow/cx/v3/example.rb', line 165

class Example
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#token_count::Integer (readonly)

Returns Output only. Estimated number of tokes current example takes when sent to the LLM.

Returns:

  • (::Integer)

    Output only. Estimated number of tokes current example takes when sent to the LLM.



165
166
167
168
# File 'proto_docs/google/cloud/dialogflow/cx/v3/example.rb', line 165

class Example
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Last time the example was updated.

Returns:



165
166
167
168
# File 'proto_docs/google/cloud/dialogflow/cx/v3/example.rb', line 165

class Example
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end