Class: Google::Cloud::Dialogflow::CX::V3::ExportPlaybookResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb

Overview

The response message for Playbooks.ExportPlaybook.

Instance Attribute Summary collapse

Instance Attribute Details

#playbook_content::String

Returns Uncompressed raw byte content for playbook.

Note: The following fields are mutually exclusive: playbook_content, playbook_uri. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Uncompressed raw byte content for playbook.

    Note: The following fields are mutually exclusive: playbook_content, playbook_uri. If a field in that set is populated, all other fields in the set will automatically be cleared.



484
485
486
487
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 484

class ExportPlaybookResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#playbook_uri::String

Returns The URI to a file containing the exported playbook. This field is populated only if playbook_uri is specified in ExportPlaybookRequest.

Note: The following fields are mutually exclusive: playbook_uri, playbook_content. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    The URI to a file containing the exported playbook. This field is populated only if playbook_uri is specified in ExportPlaybookRequest.

    Note: The following fields are mutually exclusive: playbook_uri, playbook_content. If a field in that set is populated, all other fields in the set will automatically be cleared.



484
485
486
487
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 484

class ExportPlaybookResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end