Class: Google::Cloud::Dialogflow::CX::V3::FlowTransition

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/cx/v3/trace.rb

Overview

Stores metadata of the transition to a target CX flow. Flow transition actions exit the caller playbook and enter the child flow.

Instance Attribute Summary collapse

Instance Attribute Details

#display_name::String (readonly)

Returns Output only. The display name of the flow.

Returns:

  • (::String)

    Output only. The display name of the flow.



272
273
274
275
# File 'proto_docs/google/cloud/dialogflow/cx/v3/trace.rb', line 272

class FlowTransition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#flow::String

Returns Required. The unique identifier of the flow. Format: projects/<ProjectID>/locations/<LocationID>/agents/<Agentflows/<FlowID>.

Returns:

  • (::String)

    Required. The unique identifier of the flow. Format: projects/<ProjectID>/locations/<LocationID>/agents/<Agentflows/<FlowID>.



272
273
274
275
# File 'proto_docs/google/cloud/dialogflow/cx/v3/trace.rb', line 272

class FlowTransition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end