Class: Google::Cloud::Dialogflow::CX::V3::Fulfillment::GeneratorSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/cx/v3/fulfillment.rb

Overview

Generator settings used by the LLM to generate a text response.

Defined Under Namespace

Classes: InputParametersEntry

Instance Attribute Summary collapse

Instance Attribute Details

#generator::String

Returns Required. The generator to call. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/generators/<GeneratorID>.

Returns:

  • (::String)

    Required. The generator to call. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/generators/<GeneratorID>.



170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'proto_docs/google/cloud/dialogflow/cx/v3/fulfillment.rb', line 170

class GeneratorSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class InputParametersEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#input_parameters::Google::Protobuf::Map{::String => ::String}

Returns Map from [placeholder parameter][Generator.Parameter.id] in the Generator to corresponding session parameters. By default, Dialogflow uses the session parameter with the same name to fill in the generator template. e.g. If there is a placeholder parameter city in the Generator, Dialogflow default to fill in the $city with $session.params.city. However, you may choose to fill $city with $session.params.desination-city.

  • Map key: [parameter ID][Genrator.Parameter.id]
  • Map value: session parameter name.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Map from [placeholder parameter][Generator.Parameter.id] in the Generator to corresponding session parameters. By default, Dialogflow uses the session parameter with the same name to fill in the generator template. e.g. If there is a placeholder parameter city in the Generator, Dialogflow default to fill in the $city with $session.params.city. However, you may choose to fill $city with $session.params.desination-city.

    • Map key: [parameter ID][Genrator.Parameter.id]
    • Map value: session parameter name


170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'proto_docs/google/cloud/dialogflow/cx/v3/fulfillment.rb', line 170

class GeneratorSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class InputParametersEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#output_parameter::String

Returns Required. Output parameter which should contain the generator response.

Returns:

  • (::String)

    Required. Output parameter which should contain the generator response.



170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'proto_docs/google/cloud/dialogflow/cx/v3/fulfillment.rb', line 170

class GeneratorSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class InputParametersEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end