Class: Google::Cloud::Dialogflow::CX::V3::ImportPlaybookResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb

Overview

The response message for Playbooks.ImportPlaybook.

Defined Under Namespace

Classes: ConflictingResources

Instance Attribute Summary collapse

Instance Attribute Details

#conflicting_resources::Google::Cloud::Dialogflow::CX::V3::ImportPlaybookResponse::ConflictingResources

Returns Info which resources have conflicts when [REPORT_CONFLICTS][ImportPlaybookResponse.REPORT_CONFLICTS] import strategy is set for all resources in ImportPlaybookRequest.

Returns:



448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 448

class ImportPlaybookResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Conflicting resources detected during the import process. Only filled when
  # [REPORT_CONFLICTS][ImportPlaybookResponse.REPORT_CONFLICTS] is set in the
  # request and there are conflicts in the display names.
  # @!attribute [rw] main_playbook_display_name
  #   @return [::String]
  #     Display name of conflicting main playbook.
  # @!attribute [rw] nested_playbook_display_names
  #   @return [::Array<::String>]
  #     Display names of conflicting nested playbooks.
  # @!attribute [rw] tool_display_names
  #   @return [::Array<::String>]
  #     Display names of conflicting tools.
  class ConflictingResources
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#playbook::String

Returns The unique identifier of the new playbook. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>.

Returns:

  • (::String)

    The unique identifier of the new playbook. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>.



448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 448

class ImportPlaybookResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Conflicting resources detected during the import process. Only filled when
  # [REPORT_CONFLICTS][ImportPlaybookResponse.REPORT_CONFLICTS] is set in the
  # request and there are conflicts in the display names.
  # @!attribute [rw] main_playbook_display_name
  #   @return [::String]
  #     Display name of conflicting main playbook.
  # @!attribute [rw] nested_playbook_display_names
  #   @return [::Array<::String>]
  #     Display names of conflicting nested playbooks.
  # @!attribute [rw] tool_display_names
  #   @return [::Array<::String>]
  #     Display names of conflicting tools.
  class ConflictingResources
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end