Class: Google::Cloud::Dialogflow::CX::V3::InlineSchema
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::CX::V3::InlineSchema
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/cx/v3/parameter_definition.rb
Overview
A type schema object that's specified inline.
Instance Attribute Summary collapse
-
#items ⇒ ::Google::Cloud::Dialogflow::CX::V3::TypeSchema
Schema of the elements if this is an ARRAY type.
-
#type ⇒ ::Google::Cloud::Dialogflow::CX::V3::DataType
Data type of the schema.
Instance Attribute Details
#items ⇒ ::Google::Cloud::Dialogflow::CX::V3::TypeSchema
Returns Schema of the elements if this is an ARRAY type.
110 111 112 113 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/parameter_definition.rb', line 110 class InlineSchema include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#type ⇒ ::Google::Cloud::Dialogflow::CX::V3::DataType
Returns Data type of the schema.
110 111 112 113 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/parameter_definition.rb', line 110 class InlineSchema include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |