Class: Google::Cloud::Dialogflow::CX::V3::ListPlaybookVersionsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb

Overview

The request message for Playbooks.ListPlaybookVersions.

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Returns Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.

Returns:

  • (::Integer)

    Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.



314
315
316
317
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 314

class ListPlaybookVersionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. The next_page_token value returned from a previous list request.

Returns:

  • (::String)

    Optional. The next_page_token value returned from a previous list request.



314
315
316
317
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 314

class ListPlaybookVersionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The playbook to list versions for. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>.

Returns:

  • (::String)

    Required. The playbook to list versions for. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>.



314
315
316
317
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 314

class ListPlaybookVersionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end