Class: Google::Cloud::Dialogflow::CX::V3::ListPlaybookVersionsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::CX::V3::ListPlaybookVersionsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb
Overview
The response message for Playbooks.ListPlaybookVersions.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
Token to retrieve the next page of results, or empty if there are no more results in the list.
-
#playbook_versions ⇒ ::Array<::Google::Cloud::Dialogflow::CX::V3::PlaybookVersion>
The list of playbook version.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns Token to retrieve the next page of results, or empty if there are no more results in the list.
329 330 331 332 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 329 class ListPlaybookVersionsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#playbook_versions ⇒ ::Array<::Google::Cloud::Dialogflow::CX::V3::PlaybookVersion>
The list of playbook version. There will be a maximum number of items returned based on the page_size field in the request.
329 330 331 332 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 329 class ListPlaybookVersionsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |