Class: Google::Cloud::Dialogflow::CX::V3::ListPlaybooksRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::CX::V3::ListPlaybooksRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb
Overview
The request message for Playbooks.ListPlaybooks.
Instance Attribute Summary collapse
-
#page_size ⇒ ::Integer
The maximum number of items to return in a single page.
-
#page_token ⇒ ::String
The next_page_token value returned from a previous list request.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#page_size ⇒ ::Integer
Returns The maximum number of items to return in a single page. By default 100 and at most 1000.
64 65 66 67 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 64 class ListPlaybooksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns The next_page_token value returned from a previous list request.
64 65 66 67 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 64 class ListPlaybooksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The agent to list playbooks from.
Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>.
64 65 66 67 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 64 class ListPlaybooksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |