Class: Google::Cloud::Dialogflow::CX::V3::ListPlaybooksResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::CX::V3::ListPlaybooksResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb
Overview
The response message for Playbooks.ListPlaybooks.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
Token to retrieve the next page of results, or empty if there are no more results in the list.
-
#playbooks ⇒ ::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook>
The list of playbooks.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns Token to retrieve the next page of results, or empty if there are no more results in the list.
79 80 81 82 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 79 class ListPlaybooksResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#playbooks ⇒ ::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook>
Returns The list of playbooks. There will be a maximum number of items returned based on the page_size field in the request.
79 80 81 82 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 79 class ListPlaybooksResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |