Class: Google::Cloud::Dialogflow::CX::V3::ListToolVersionsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/cx/v3/tool.rb

Overview

The request message for Tools.ListToolVersions.

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Returns Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.

Returns:

  • (::Integer)

    Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.



470
471
472
473
# File 'proto_docs/google/cloud/dialogflow/cx/v3/tool.rb', line 470

class ListToolVersionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. The next_page_token value returned from a previous list request.

Returns:

  • (::String)

    Optional. The next_page_token value returned from a previous list request.



470
471
472
473
# File 'proto_docs/google/cloud/dialogflow/cx/v3/tool.rb', line 470

class ListToolVersionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent of the tool versions. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/tools/<ToolID>.

Returns:

  • (::String)

    Required. The parent of the tool versions. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/tools/<ToolID>.



470
471
472
473
# File 'proto_docs/google/cloud/dialogflow/cx/v3/tool.rb', line 470

class ListToolVersionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end