Class: Google::Cloud::Dialogflow::CX::V3::ListToolVersionsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::CX::V3::ListToolVersionsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/cx/v3/tool.rb
Overview
The response message for Tools.ListToolVersions.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
Token to retrieve the next page of results, or empty if there are no more results in the list.
-
#tool_versions ⇒ ::Array<::Google::Cloud::Dialogflow::CX::V3::ToolVersion>
The list of tool versions.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns Token to retrieve the next page of results, or empty if there are no more results in the list.
485 486 487 488 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/tool.rb', line 485 class ListToolVersionsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tool_versions ⇒ ::Array<::Google::Cloud::Dialogflow::CX::V3::ToolVersion>
The list of tool versions. There will be a maximum number of items returned based on the page_size field in the request.
485 486 487 488 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/tool.rb', line 485 class ListToolVersionsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |