Class: Google::Cloud::Dialogflow::CX::V3::PageInfo::FormInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/cx/v3/webhook.rb

Overview

Represents form information.

Defined Under Namespace

Classes: ParameterInfo

Instance Attribute Summary collapse

Instance Attribute Details

#parameter_info::Array<::Google::Cloud::Dialogflow::CX::V3::PageInfo::FormInfo::ParameterInfo>

Returns Optional for both WebhookRequest and WebhookResponse. The parameters contained in the form. Note that the webhook cannot add or remove any form parameter.

Returns:



655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
# File 'proto_docs/google/cloud/dialogflow/cx/v3/webhook.rb', line 655

class FormInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents parameter information.
  # @!attribute [rw] display_name
  #   @return [::String]
  #     Always present for
  #     {::Google::Cloud::Dialogflow::CX::V3::WebhookRequest WebhookRequest}.
  #     Required for
  #     {::Google::Cloud::Dialogflow::CX::V3::WebhookResponse WebhookResponse}.
  #     The human-readable name of the parameter, unique within the form. This
  #     field cannot be modified by the webhook.
  # @!attribute [rw] required
  #   @return [::Boolean]
  #     Optional for both
  #     {::Google::Cloud::Dialogflow::CX::V3::WebhookRequest WebhookRequest} and
  #     {::Google::Cloud::Dialogflow::CX::V3::WebhookResponse WebhookResponse}.
  #     Indicates whether the parameter is required. Optional parameters will
  #     not trigger prompts; however, they are filled if the user specifies
  #     them. Required parameters must be filled before form filling concludes.
  # @!attribute [rw] state
  #   @return [::Google::Cloud::Dialogflow::CX::V3::PageInfo::FormInfo::ParameterInfo::ParameterState]
  #     Always present for
  #     {::Google::Cloud::Dialogflow::CX::V3::WebhookRequest WebhookRequest}.
  #     Required for
  #     {::Google::Cloud::Dialogflow::CX::V3::WebhookResponse WebhookResponse}. The
  #     state of the parameter. This field can be set to
  #     {::Google::Cloud::Dialogflow::CX::V3::PageInfo::FormInfo::ParameterInfo::ParameterState::INVALID INVALID}
  #     by the webhook to invalidate the parameter; other values set by the
  #     webhook will be ignored.
  # @!attribute [rw] value
  #   @return [::Google::Protobuf::Value]
  #     Optional for both
  #     {::Google::Cloud::Dialogflow::CX::V3::WebhookRequest WebhookRequest} and
  #     {::Google::Cloud::Dialogflow::CX::V3::WebhookResponse WebhookResponse}. The
  #     value of the parameter. This field can be set by the webhook to change
  #     the parameter value.
  # @!attribute [rw] just_collected
  #   @return [::Boolean]
  #     Optional for
  #     {::Google::Cloud::Dialogflow::CX::V3::WebhookRequest WebhookRequest}. Ignored
  #     for {::Google::Cloud::Dialogflow::CX::V3::WebhookResponse WebhookResponse}.
  #     Indicates if the parameter value was just collected on the last
  #     conversation turn.
  class ParameterInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents the state of a parameter.
    module ParameterState
      # Not specified. This value should be never used.
      PARAMETER_STATE_UNSPECIFIED = 0

      # Indicates that the parameter does not have a value.
      EMPTY = 1

      # Indicates that the parameter value is invalid. This field can be used
      # by the webhook to invalidate the parameter and ask the server to
      # collect it from the user again.
      INVALID = 2

      # Indicates that the parameter has a value.
      FILLED = 3
    end
  end
end