Class: Google::Cloud::Dialogflow::CX::V3::PageInfo::FormInfo::ParameterInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::CX::V3::PageInfo::FormInfo::ParameterInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/cx/v3/webhook.rb
Overview
Represents parameter information.
Defined Under Namespace
Modules: ParameterState
Instance Attribute Summary collapse
-
#display_name ⇒ ::String
Always present for WebhookRequest.
-
#just_collected ⇒ ::Boolean
Optional for WebhookRequest.
-
#required ⇒ ::Boolean
Optional for both WebhookRequest and WebhookResponse.
-
#state ⇒ ::Google::Cloud::Dialogflow::CX::V3::PageInfo::FormInfo::ParameterInfo::ParameterState
Always present for WebhookRequest.
-
#value ⇒ ::Google::Protobuf::Value
Optional for both WebhookRequest and WebhookResponse.
Instance Attribute Details
#display_name ⇒ ::String
Returns Always present for WebhookRequest. Required for WebhookResponse. The human-readable name of the parameter, unique within the form. This field cannot be modified by the webhook.
700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/webhook.rb', line 700 class ParameterInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the state of a parameter. module ParameterState # Not specified. This value should be never used. PARAMETER_STATE_UNSPECIFIED = 0 # Indicates that the parameter does not have a value. EMPTY = 1 # Indicates that the parameter value is invalid. This field can be used # by the webhook to invalidate the parameter and ask the server to # collect it from the user again. INVALID = 2 # Indicates that the parameter has a value. FILLED = 3 end end |
#just_collected ⇒ ::Boolean
Returns Optional for WebhookRequest. Ignored for WebhookResponse. Indicates if the parameter value was just collected on the last conversation turn.
700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/webhook.rb', line 700 class ParameterInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the state of a parameter. module ParameterState # Not specified. This value should be never used. PARAMETER_STATE_UNSPECIFIED = 0 # Indicates that the parameter does not have a value. EMPTY = 1 # Indicates that the parameter value is invalid. This field can be used # by the webhook to invalidate the parameter and ask the server to # collect it from the user again. INVALID = 2 # Indicates that the parameter has a value. FILLED = 3 end end |
#required ⇒ ::Boolean
Returns Optional for both WebhookRequest and WebhookResponse. Indicates whether the parameter is required. Optional parameters will not trigger prompts; however, they are filled if the user specifies them. Required parameters must be filled before form filling concludes.
700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/webhook.rb', line 700 class ParameterInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the state of a parameter. module ParameterState # Not specified. This value should be never used. PARAMETER_STATE_UNSPECIFIED = 0 # Indicates that the parameter does not have a value. EMPTY = 1 # Indicates that the parameter value is invalid. This field can be used # by the webhook to invalidate the parameter and ask the server to # collect it from the user again. INVALID = 2 # Indicates that the parameter has a value. FILLED = 3 end end |
#state ⇒ ::Google::Cloud::Dialogflow::CX::V3::PageInfo::FormInfo::ParameterInfo::ParameterState
Returns Always present for WebhookRequest. Required for WebhookResponse. The state of the parameter. This field can be set to INVALID by the webhook to invalidate the parameter; other values set by the webhook will be ignored.
700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/webhook.rb', line 700 class ParameterInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the state of a parameter. module ParameterState # Not specified. This value should be never used. PARAMETER_STATE_UNSPECIFIED = 0 # Indicates that the parameter does not have a value. EMPTY = 1 # Indicates that the parameter value is invalid. This field can be used # by the webhook to invalidate the parameter and ask the server to # collect it from the user again. INVALID = 2 # Indicates that the parameter has a value. FILLED = 3 end end |
#value ⇒ ::Google::Protobuf::Value
Returns Optional for both WebhookRequest and WebhookResponse. The value of the parameter. This field can be set by the webhook to change the parameter value.
700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/webhook.rb', line 700 class ParameterInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the state of a parameter. module ParameterState # Not specified. This value should be never used. PARAMETER_STATE_UNSPECIFIED = 0 # Indicates that the parameter does not have a value. EMPTY = 1 # Indicates that the parameter value is invalid. This field can be used # by the webhook to invalidate the parameter and ask the server to # collect it from the user again. INVALID = 2 # Indicates that the parameter has a value. FILLED = 3 end end |