Class: Google::Cloud::Dialogflow::CX::V3::ParameterDefinition

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/cx/v3/parameter_definition.rb

Overview

Defines the properties of a parameter. Used to define parameters used in the agent and the input / output parameters for each fulfillment.

Defined Under Namespace

Modules: ParameterType

Instance Attribute Summary collapse

Instance Attribute Details

#description::String

Returns Human-readable description of the parameter. Limited to 300 characters.

Returns:

  • (::String)

    Human-readable description of the parameter. Limited to 300 characters.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'proto_docs/google/cloud/dialogflow/cx/v3/parameter_definition.rb', line 41

class ParameterDefinition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Parameter types are used for validation.
  # These types are consistent with
  # {::Google::Protobuf::Value google.protobuf.Value}.
  module ParameterType
    # Not specified. No validation will be performed.
    PARAMETER_TYPE_UNSPECIFIED = 0

    # Represents any string value.
    STRING = 1

    # Represents any number value.
    NUMBER = 2

    # Represents a boolean value.
    BOOLEAN = 3

    # Represents a null value.
    NULL = 4

    # Represents any object value.
    OBJECT = 5

    # Represents a repeated value.
    LIST = 6
  end
end

#name::String

Returns Required. Name of parameter.

Returns:

  • (::String)

    Required. Name of parameter.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'proto_docs/google/cloud/dialogflow/cx/v3/parameter_definition.rb', line 41

class ParameterDefinition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Parameter types are used for validation.
  # These types are consistent with
  # {::Google::Protobuf::Value google.protobuf.Value}.
  module ParameterType
    # Not specified. No validation will be performed.
    PARAMETER_TYPE_UNSPECIFIED = 0

    # Represents any string value.
    STRING = 1

    # Represents any number value.
    NUMBER = 2

    # Represents a boolean value.
    BOOLEAN = 3

    # Represents a null value.
    NULL = 4

    # Represents any object value.
    OBJECT = 5

    # Represents a repeated value.
    LIST = 6
  end
end

#type::Google::Cloud::Dialogflow::CX::V3::ParameterDefinition::ParameterType

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns Type of parameter.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'proto_docs/google/cloud/dialogflow/cx/v3/parameter_definition.rb', line 41

class ParameterDefinition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Parameter types are used for validation.
  # These types are consistent with
  # {::Google::Protobuf::Value google.protobuf.Value}.
  module ParameterType
    # Not specified. No validation will be performed.
    PARAMETER_TYPE_UNSPECIFIED = 0

    # Represents any string value.
    STRING = 1

    # Represents any number value.
    NUMBER = 2

    # Represents a boolean value.
    BOOLEAN = 3

    # Represents a null value.
    NULL = 4

    # Represents any object value.
    OBJECT = 5

    # Represents a repeated value.
    LIST = 6
  end
end

#type_schema::Google::Cloud::Dialogflow::CX::V3::TypeSchema

Returns Optional. Type schema of parameter.

Returns:



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'proto_docs/google/cloud/dialogflow/cx/v3/parameter_definition.rb', line 41

class ParameterDefinition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Parameter types are used for validation.
  # These types are consistent with
  # {::Google::Protobuf::Value google.protobuf.Value}.
  module ParameterType
    # Not specified. No validation will be performed.
    PARAMETER_TYPE_UNSPECIFIED = 0

    # Represents any string value.
    STRING = 1

    # Represents any number value.
    NUMBER = 2

    # Represents a boolean value.
    BOOLEAN = 3

    # Represents a null value.
    NULL = 4

    # Represents any object value.
    OBJECT = 5

    # Represents a repeated value.
    LIST = 6
  end
end