Class: Google::Cloud::Dialogflow::CX::V3::PlaybookImportStrategy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb

Overview

The playbook import strategy used for resource conflict resolution associated with an ImportPlaybookRequest.

Instance Attribute Summary collapse

Instance Attribute Details

#main_playbook_import_strategy::Google::Cloud::Dialogflow::CX::V3::ImportStrategy

Returns Optional. Specifies the import strategy used when resolving conflicts with the main playbook. If not specified, 'CREATE_NEW' is assumed.

Returns:



431
432
433
434
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 431

class PlaybookImportStrategy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#nested_resource_import_strategy::Google::Cloud::Dialogflow::CX::V3::ImportStrategy

Returns Optional. Specifies the import strategy used when resolving referenced playbook/flow conflicts. If not specified, 'CREATE_NEW' is assumed.

Returns:



431
432
433
434
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 431

class PlaybookImportStrategy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tool_import_strategy::Google::Cloud::Dialogflow::CX::V3::ImportStrategy

Returns Optional. Specifies the import strategy used when resolving tool conflicts. If not specified, 'CREATE_NEW' is assumed. This will be applied after the main playbook and nested resource import strategies, meaning if the playbook that references the tool is skipped, the tool will also be skipped.

Returns:

  • (::Google::Cloud::Dialogflow::CX::V3::ImportStrategy)

    Optional. Specifies the import strategy used when resolving tool conflicts. If not specified, 'CREATE_NEW' is assumed. This will be applied after the main playbook and nested resource import strategies, meaning if the playbook that references the tool is skipped, the tool will also be skipped.



431
432
433
434
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 431

class PlaybookImportStrategy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end