Class: Google::Cloud::Dialogflow::CX::V3::PlaybookInput

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/cx/v3/trace.rb

Overview

Input of the playbook.

Instance Attribute Summary collapse

Instance Attribute Details

#preceding_conversation_summary::String

Returns Optional. Summary string of the preceding conversation for the child playbook invocation.

Returns:

  • (::String)

    Optional. Summary string of the preceding conversation for the child playbook invocation.



107
108
109
110
# File 'proto_docs/google/cloud/dialogflow/cx/v3/trace.rb', line 107

class PlaybookInput
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end