Class: Google::Cloud::Dialogflow::CX::V3::PlaybookOutput

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/cx/v3/trace.rb

Overview

Output of the playbook.

Instance Attribute Summary collapse

Instance Attribute Details

#execution_summary::String

Returns Optional. Summary string of the execution result of the child playbook.

Returns:

  • (::String)

    Optional. Summary string of the execution result of the child playbook.



116
117
118
119
# File 'proto_docs/google/cloud/dialogflow/cx/v3/trace.rb', line 116

class PlaybookOutput
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end