Class: Google::Cloud::Dialogflow::CX::V3::PlaybookVersion

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb

Overview

Playbook version is a snapshot of the playbook at certain timestamp.

Instance Attribute Summary collapse

Instance Attribute Details

#description::String

Returns Optional. The description of the playbook version.

Returns:

  • (::String)

    Optional. The description of the playbook version.



261
262
263
264
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 261

class PlaybookVersion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#examples::Array<::Google::Cloud::Dialogflow::CX::V3::Example> (readonly)

Returns Output only. Snapshot of the examples belonging to the playbook when the playbook version is created.

Returns:



261
262
263
264
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 261

class PlaybookVersion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns The unique identifier of the playbook version. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>/versions/<VersionID>.

Returns:

  • (::String)

    The unique identifier of the playbook version. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>/versions/<VersionID>.



261
262
263
264
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 261

class PlaybookVersion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#playbook::Google::Cloud::Dialogflow::CX::V3::Playbook (readonly)

Returns Output only. Snapshot of the playbook when the playbook version is created.

Returns:



261
262
263
264
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 261

class PlaybookVersion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Last time the playbook version was created or modified.

Returns:



261
262
263
264
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 261

class PlaybookVersion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end