Class: Google::Cloud::Dialogflow::CX::V3::Playbooks::Rest::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/dialogflow/cx/v3/playbooks/rest/client.rb

Overview

REST client for the Playbooks service.

Service for managing Playbooks.

Defined Under Namespace

Classes: Configuration

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#agent_path, #example_path, #flow_path, #generator_path, #playbook_path, #playbook_version_path, #tool_path, #webhook_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new Playbooks REST client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::Dialogflow::CX::V3::Playbooks::Rest::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::Dialogflow::CX::V3::Playbooks::Rest::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Playbooks client.

Yield Parameters:



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/google/cloud/dialogflow/cx/v3/playbooks/rest/client.rb', line 133

def initialize
  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end

  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @operations_client = ::Google::Cloud::Dialogflow::CX::V3::Playbooks::Rest::Operations.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @config.endpoint
    config.universe_domain = @config.universe_domain
  end

  @playbooks_stub = ::Google::Cloud::Dialogflow::CX::V3::Playbooks::Rest::ServiceStub.new(
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    credentials: credentials,
    logger: @config.logger
  )

  @playbooks_stub.logger(stub: true)&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end

  @location_client = Google::Cloud::Location::Locations::Rest::Client.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @playbooks_stub.endpoint
    config.universe_domain = @playbooks_stub.universe_domain
    config.bindings_override = @config.bindings_override
    config.logger = @playbooks_stub.logger if config.respond_to? :logger=
  end
end

Instance Attribute Details

#location_clientGoogle::Cloud::Location::Locations::Rest::Client (readonly)

Get the associated client for mix-in of the Locations.

Returns:

  • (Google::Cloud::Location::Locations::Rest::Client)


203
204
205
# File 'lib/google/cloud/dialogflow/cx/v3/playbooks/rest/client.rb', line 203

def location_client
  @location_client
end

#operations_client::Google::Cloud::Dialogflow::CX::V3::Playbooks::Rest::Operations (readonly)

Get the associated client for long-running operations.



196
197
198
# File 'lib/google/cloud/dialogflow/cx/v3/playbooks/rest/client.rb', line 196

def operations_client
  @operations_client
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the Playbooks Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all Playbooks clients
::Google::Cloud::Dialogflow::CX::V3::Playbooks::Rest::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/google/cloud/dialogflow/cx/v3/playbooks/rest/client.rb', line 66

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "Dialogflow", "CX", "V3"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.timeout = 60.0
    default_config.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the Playbooks Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



103
104
105
106
# File 'lib/google/cloud/dialogflow/cx/v3/playbooks/rest/client.rb', line 103

def configure
  yield @config if block_given?
  @config
end

#create_playbook(request, options = nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::Playbook #create_playbook(parent: nil, playbook: nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::Playbook

Creates a playbook in a specified agent.

Examples:

Basic example

require "google/cloud/dialogflow/cx/v3"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dialogflow::CX::V3::Playbooks::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dialogflow::CX::V3::CreatePlaybookRequest.new

# Call the create_playbook method.
result = client.create_playbook request

# The returned object is of type Google::Cloud::Dialogflow::CX::V3::Playbook.
p result

Overloads:

  • #create_playbook(request, options = nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::Playbook

    Pass arguments to create_playbook via a request object, either of type CreatePlaybookRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dialogflow::CX::V3::CreatePlaybookRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #create_playbook(parent: nil, playbook: nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::Playbook

    Pass arguments to create_playbook via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The agent to create a playbook for. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>.

    • playbook (::Google::Cloud::Dialogflow::CX::V3::Playbook, ::Hash) (defaults to: nil)

      Required. The playbook to create.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/google/cloud/dialogflow/cx/v3/playbooks/rest/client.rb', line 262

def create_playbook request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dialogflow::CX::V3::CreatePlaybookRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_playbook..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dialogflow::CX::V3::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.create_playbook.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_playbook.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @playbooks_stub.create_playbook request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#create_playbook_version(request, options = nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::PlaybookVersion #create_playbook_version(parent: nil, playbook_version: nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::PlaybookVersion

Creates a version for the specified Playbook.

Examples:

Basic example

require "google/cloud/dialogflow/cx/v3"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dialogflow::CX::V3::Playbooks::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dialogflow::CX::V3::CreatePlaybookVersionRequest.new

# Call the create_playbook_version method.
result = client.create_playbook_version request

# The returned object is of type Google::Cloud::Dialogflow::CX::V3::PlaybookVersion.
p result

Overloads:

  • #create_playbook_version(request, options = nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::PlaybookVersion

    Pass arguments to create_playbook_version via a request object, either of type CreatePlaybookVersionRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dialogflow::CX::V3::CreatePlaybookVersionRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #create_playbook_version(parent: nil, playbook_version: nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::PlaybookVersion

    Pass arguments to create_playbook_version via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The playbook to create a version for. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>.

    • playbook_version (::Google::Cloud::Dialogflow::CX::V3::PlaybookVersion, ::Hash) (defaults to: nil)

      Required. The playbook version to create.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
# File 'lib/google/cloud/dialogflow/cx/v3/playbooks/rest/client.rb', line 882

def create_playbook_version request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dialogflow::CX::V3::CreatePlaybookVersionRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_playbook_version..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dialogflow::CX::V3::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.create_playbook_version.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_playbook_version.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @playbooks_stub.create_playbook_version request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#delete_playbook(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_playbook(name: nil) ⇒ ::Google::Protobuf::Empty

Deletes a specified playbook.

Examples:

Basic example

require "google/cloud/dialogflow/cx/v3"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dialogflow::CX::V3::Playbooks::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dialogflow::CX::V3::DeletePlaybookRequest.new

# Call the delete_playbook method.
result = client.delete_playbook request

# The returned object is of type Google::Protobuf::Empty.
p result

Overloads:

  • #delete_playbook(request, options = nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_playbook via a request object, either of type DeletePlaybookRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dialogflow::CX::V3::DeletePlaybookRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #delete_playbook(name: nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_playbook via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the playbook to delete. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
# File 'lib/google/cloud/dialogflow/cx/v3/playbooks/rest/client.rb', line 342

def delete_playbook request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dialogflow::CX::V3::DeletePlaybookRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.delete_playbook..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dialogflow::CX::V3::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.delete_playbook.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.delete_playbook.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @playbooks_stub.delete_playbook request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#delete_playbook_version(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_playbook_version(name: nil) ⇒ ::Google::Protobuf::Empty

Deletes the specified version of the Playbook.

Examples:

Basic example

require "google/cloud/dialogflow/cx/v3"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dialogflow::CX::V3::Playbooks::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dialogflow::CX::V3::DeletePlaybookVersionRequest.new

# Call the delete_playbook_version method.
result = client.delete_playbook_version request

# The returned object is of type Google::Protobuf::Empty.
p result

Overloads:

  • #delete_playbook_version(request, options = nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_playbook_version via a request object, either of type DeletePlaybookVersionRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dialogflow::CX::V3::DeletePlaybookVersionRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #delete_playbook_version(name: nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_playbook_version via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the playbook version to delete. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>/versions/<VersionID>.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
# File 'lib/google/cloud/dialogflow/cx/v3/playbooks/rest/client.rb', line 1214

def delete_playbook_version request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dialogflow::CX::V3::DeletePlaybookVersionRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.delete_playbook_version..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dialogflow::CX::V3::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.delete_playbook_version.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.delete_playbook_version.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @playbooks_stub.delete_playbook_version request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#export_playbook(request, options = nil) ⇒ ::Gapic::Operation #export_playbook(name: nil, playbook_uri: nil, data_format: nil) ⇒ ::Gapic::Operation

Exports the specified playbook to a binary file.

Note that resources (e.g. examples, tools) that the playbook references will also be exported.

Examples:

Basic example

require "google/cloud/dialogflow/cx/v3"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dialogflow::CX::V3::Playbooks::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dialogflow::CX::V3::ExportPlaybookRequest.new

# Call the export_playbook method.
result = client.export_playbook request

# The returned object is of type Gapic::Operation. You can use it to
# check the status of an operation, cancel it, or wait for results.
# Here is how to wait for a response.
result.wait_until_done! timeout: 60
if result.response?
  p result.response
else
  puts "No response received."
end

Overloads:

  • #export_playbook(request, options = nil) ⇒ ::Gapic::Operation

    Pass arguments to export_playbook via a request object, either of type ExportPlaybookRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dialogflow::CX::V3::ExportPlaybookRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #export_playbook(name: nil, playbook_uri: nil, data_format: nil) ⇒ ::Gapic::Operation

    Pass arguments to export_playbook via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the playbook to export. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>.

    • playbook_uri (::String) (defaults to: nil)

      Optional. The Google Cloud Storage URI to export the playbook to. The format of this URI must be gs://<bucket-name>/<object-name>. If left unspecified, the serialized playbook is returned inline.

      Dialogflow performs a write operation for the Cloud Storage object on the caller's behalf, so your request authentication must have write permissions for the object. For more information, see Dialogflow access control.

    • data_format (::Google::Cloud::Dialogflow::CX::V3::ExportPlaybookRequest::DataFormat) (defaults to: nil)

      Optional. The data format of the exported agent. If not specified, BLOB is assumed.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

  • result (::Gapic::Operation)
  • operation (::Gapic::Rest::TransportOperation)

Returns:

  • (::Gapic::Operation)

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
# File 'lib/google/cloud/dialogflow/cx/v3/playbooks/rest/client.rb', line 616

def export_playbook request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dialogflow::CX::V3::ExportPlaybookRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.export_playbook..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dialogflow::CX::V3::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.export_playbook.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.export_playbook.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @playbooks_stub.export_playbook request, options do |result, operation|
    result = ::Gapic::Operation.new result, @operations_client, options: options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_playbook(request, options = nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::Playbook #get_playbook(name: nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::Playbook

Retrieves the specified Playbook.

Examples:

Basic example

require "google/cloud/dialogflow/cx/v3"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dialogflow::CX::V3::Playbooks::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dialogflow::CX::V3::GetPlaybookRequest.new

# Call the get_playbook method.
result = client.get_playbook request

# The returned object is of type Google::Cloud::Dialogflow::CX::V3::Playbook.
p result

Overloads:

  • #get_playbook(request, options = nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::Playbook

    Pass arguments to get_playbook via a request object, either of type GetPlaybookRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dialogflow::CX::V3::GetPlaybookRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_playbook(name: nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::Playbook

    Pass arguments to get_playbook via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the playbook. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
# File 'lib/google/cloud/dialogflow/cx/v3/playbooks/rest/client.rb', line 512

def get_playbook request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dialogflow::CX::V3::GetPlaybookRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_playbook..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dialogflow::CX::V3::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_playbook.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_playbook.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @playbooks_stub.get_playbook request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_playbook_version(request, options = nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::PlaybookVersion #get_playbook_version(name: nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::PlaybookVersion

Retrieves the specified version of the Playbook.

Examples:

Basic example

require "google/cloud/dialogflow/cx/v3"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dialogflow::CX::V3::Playbooks::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dialogflow::CX::V3::GetPlaybookVersionRequest.new

# Call the get_playbook_version method.
result = client.get_playbook_version request

# The returned object is of type Google::Cloud::Dialogflow::CX::V3::PlaybookVersion.
p result

Overloads:

  • #get_playbook_version(request, options = nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::PlaybookVersion

    Pass arguments to get_playbook_version via a request object, either of type GetPlaybookVersionRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dialogflow::CX::V3::GetPlaybookVersionRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_playbook_version(name: nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::PlaybookVersion

    Pass arguments to get_playbook_version via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the playbook version. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>/versions/<VersionID>.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
# File 'lib/google/cloud/dialogflow/cx/v3/playbooks/rest/client.rb', line 962

def get_playbook_version request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dialogflow::CX::V3::GetPlaybookVersionRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_playbook_version..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dialogflow::CX::V3::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_playbook_version.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_playbook_version.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @playbooks_stub.get_playbook_version request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#import_playbook(request, options = nil) ⇒ ::Gapic::Operation #import_playbook(parent: nil, playbook_uri: nil, playbook_content: nil, import_strategy: nil) ⇒ ::Gapic::Operation

Imports the specified playbook to the specified agent from a binary file.

Examples:

Basic example

require "google/cloud/dialogflow/cx/v3"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dialogflow::CX::V3::Playbooks::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dialogflow::CX::V3::ImportPlaybookRequest.new

# Call the import_playbook method.
result = client.import_playbook request

# The returned object is of type Gapic::Operation. You can use it to
# check the status of an operation, cancel it, or wait for results.
# Here is how to wait for a response.
result.wait_until_done! timeout: 60
if result.response?
  p result.response
else
  puts "No response received."
end

Overloads:

  • #import_playbook(request, options = nil) ⇒ ::Gapic::Operation

    Pass arguments to import_playbook via a request object, either of type ImportPlaybookRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dialogflow::CX::V3::ImportPlaybookRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #import_playbook(parent: nil, playbook_uri: nil, playbook_content: nil, import_strategy: nil) ⇒ ::Gapic::Operation

    Pass arguments to import_playbook via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The agent to import the playbook into. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>.

    • playbook_uri (::String) (defaults to: nil)

      Dialogflow access control.

      Note: The following parameters are mutually exclusive: playbook_uri, playbook_content. At most one of these parameters can be set. If more than one is set, only one will be used, and it is not defined which one.

    • playbook_content (::String) (defaults to: nil)

      Uncompressed raw byte content for playbook.

      Note: The following parameters are mutually exclusive: playbook_content, playbook_uri. At most one of these parameters can be set. If more than one is set, only one will be used, and it is not defined which one.

    • import_strategy (::Google::Cloud::Dialogflow::CX::V3::PlaybookImportStrategy, ::Hash) (defaults to: nil)

      Optional. Specifies the import strategy used when resolving resource conflicts.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

  • result (::Gapic::Operation)
  • operation (::Gapic::Rest::TransportOperation)

Returns:

  • (::Gapic::Operation)

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
# File 'lib/google/cloud/dialogflow/cx/v3/playbooks/rest/client.rb', line 717

def import_playbook request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dialogflow::CX::V3::ImportPlaybookRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.import_playbook..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dialogflow::CX::V3::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.import_playbook.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.import_playbook.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @playbooks_stub.import_playbook request, options do |result, operation|
    result = ::Gapic::Operation.new result, @operations_client, options: options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_playbook_versions(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dialogflow::CX::V3::PlaybookVersion> #list_playbook_versions(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dialogflow::CX::V3::PlaybookVersion>

Lists versions for the specified Playbook.

Examples:

Basic example

require "google/cloud/dialogflow/cx/v3"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dialogflow::CX::V3::Playbooks::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dialogflow::CX::V3::ListPlaybookVersionsRequest.new

# Call the list_playbook_versions method.
result = client.list_playbook_versions request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::Dialogflow::CX::V3::PlaybookVersion.
  p item
end

Overloads:

  • #list_playbook_versions(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dialogflow::CX::V3::PlaybookVersion>

    Pass arguments to list_playbook_versions via a request object, either of type ListPlaybookVersionsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dialogflow::CX::V3::ListPlaybookVersionsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #list_playbook_versions(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dialogflow::CX::V3::PlaybookVersion>

    Pass arguments to list_playbook_versions via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The playbook to list versions for. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>.

    • page_size (::Integer) (defaults to: nil)

      Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.

    • page_token (::String) (defaults to: nil)

      Optional. The next_page_token value returned from a previous list request.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
1167
# File 'lib/google/cloud/dialogflow/cx/v3/playbooks/rest/client.rb', line 1132

def list_playbook_versions request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dialogflow::CX::V3::ListPlaybookVersionsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_playbook_versions..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dialogflow::CX::V3::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_playbook_versions.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_playbook_versions.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @playbooks_stub.list_playbook_versions request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @playbooks_stub, :list_playbook_versions, "playbook_versions", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_playbooks(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dialogflow::CX::V3::Playbook> #list_playbooks(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dialogflow::CX::V3::Playbook>

Returns a list of playbooks in the specified agent.

Examples:

Basic example

require "google/cloud/dialogflow/cx/v3"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dialogflow::CX::V3::Playbooks::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dialogflow::CX::V3::ListPlaybooksRequest.new

# Call the list_playbooks method.
result = client.list_playbooks request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::Dialogflow::CX::V3::Playbook.
  p item
end

Overloads:

  • #list_playbooks(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dialogflow::CX::V3::Playbook>

    Pass arguments to list_playbooks via a request object, either of type ListPlaybooksRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dialogflow::CX::V3::ListPlaybooksRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #list_playbooks(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dialogflow::CX::V3::Playbook>

    Pass arguments to list_playbooks via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The agent to list playbooks from. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>.

    • page_size (::Integer) (defaults to: nil)

      The maximum number of items to return in a single page. By default 100 and at most 1000.

    • page_token (::String) (defaults to: nil)

      The next_page_token value returned from a previous list request.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'lib/google/cloud/dialogflow/cx/v3/playbooks/rest/client.rb', line 430

def list_playbooks request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dialogflow::CX::V3::ListPlaybooksRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_playbooks..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dialogflow::CX::V3::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_playbooks.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_playbooks.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @playbooks_stub.list_playbooks request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @playbooks_stub, :list_playbooks, "playbooks", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


210
211
212
# File 'lib/google/cloud/dialogflow/cx/v3/playbooks/rest/client.rb', line 210

def logger
  @playbooks_stub.logger
end

#restore_playbook_version(request, options = nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::RestorePlaybookVersionResponse #restore_playbook_version(name: nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::RestorePlaybookVersionResponse

Retrieves the specified version of the Playbook and stores it as the current playbook draft, returning the playbook with resources updated.

Examples:

Basic example

require "google/cloud/dialogflow/cx/v3"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dialogflow::CX::V3::Playbooks::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dialogflow::CX::V3::RestorePlaybookVersionRequest.new

# Call the restore_playbook_version method.
result = client.restore_playbook_version request

# The returned object is of type Google::Cloud::Dialogflow::CX::V3::RestorePlaybookVersionResponse.
p result

Overloads:

  • #restore_playbook_version(request, options = nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::RestorePlaybookVersionResponse

    Pass arguments to restore_playbook_version via a request object, either of type RestorePlaybookVersionRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dialogflow::CX::V3::RestorePlaybookVersionRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #restore_playbook_version(name: nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::RestorePlaybookVersionResponse

    Pass arguments to restore_playbook_version via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the playbook version. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>/versions/<VersionID>.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
# File 'lib/google/cloud/dialogflow/cx/v3/playbooks/rest/client.rb', line 1043

def restore_playbook_version request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dialogflow::CX::V3::RestorePlaybookVersionRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.restore_playbook_version..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dialogflow::CX::V3::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.restore_playbook_version.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.restore_playbook_version.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @playbooks_stub.restore_playbook_version request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


113
114
115
# File 'lib/google/cloud/dialogflow/cx/v3/playbooks/rest/client.rb', line 113

def universe_domain
  @playbooks_stub.universe_domain
end

#update_playbook(request, options = nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::Playbook #update_playbook(playbook: nil, update_mask: nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::Playbook

Updates the specified Playbook.

Examples:

Basic example

require "google/cloud/dialogflow/cx/v3"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dialogflow::CX::V3::Playbooks::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dialogflow::CX::V3::UpdatePlaybookRequest.new

# Call the update_playbook method.
result = client.update_playbook request

# The returned object is of type Google::Cloud::Dialogflow::CX::V3::Playbook.
p result

Overloads:

  • #update_playbook(request, options = nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::Playbook

    Pass arguments to update_playbook via a request object, either of type UpdatePlaybookRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dialogflow::CX::V3::UpdatePlaybookRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #update_playbook(playbook: nil, update_mask: nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::Playbook

    Pass arguments to update_playbook via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
# File 'lib/google/cloud/dialogflow/cx/v3/playbooks/rest/client.rb', line 800

def update_playbook request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dialogflow::CX::V3::UpdatePlaybookRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_playbook..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dialogflow::CX::V3::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.update_playbook.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_playbook.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @playbooks_stub.update_playbook request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end