Class: Google::Cloud::Dialogflow::CX::V3::ResponseMessage::Text
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::CX::V3::ResponseMessage::Text
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/cx/v3/response_message.rb
Overview
The text response message.
Instance Attribute Summary collapse
-
#allow_playback_interruption ⇒ ::Boolean
readonly
Output only.
-
#text ⇒ ::Array<::String>
Required.
Instance Attribute Details
#allow_playback_interruption ⇒ ::Boolean (readonly)
Returns Output only. Whether the playback of this message can be interrupted by the end user's speech and the client can then starts the next Dialogflow request.
137 138 139 140 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/response_message.rb', line 137 class Text include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#text ⇒ ::Array<::String>
Returns Required. A collection of text response variants. If multiple variants are defined, only one text response variant is returned at runtime.
137 138 139 140 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/response_message.rb', line 137 class Text include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |