Module: Google::Cloud::Dialogflow::CX::V3::SafetySettings::PhraseMatchStrategy

Defined in:
proto_docs/google/cloud/dialogflow/cx/v3/safety_settings.rb

Overview

Strategy for matching phrases.

Constant Summary collapse

PHRASE_MATCH_STRATEGY_UNSPECIFIED =

Unspecified, defaults to PARTIAL_MATCH.

0
PARTIAL_MATCH =

Text that contains the phrase as a substring will be matched, e.g. "foo" will match "afoobar".

1
WORD_MATCH =

Text that contains the tokenized words of the phrase will be matched, e.g. "foo" will match "a foo bar" and "foo bar", but not "foobar".

2