Class: Google::Cloud::Dialogflow::CX::V3::SecuritySettings::AudioExportSettings
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::CX::V3::SecuritySettings::AudioExportSettings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/cx/v3/security_settings.rb
Overview
Settings for exporting audio.
Defined Under Namespace
Modules: AudioFormat
Instance Attribute Summary collapse
-
#audio_export_pattern ⇒ ::String
Filename pattern for exported audio.
-
#audio_format ⇒ ::Google::Cloud::Dialogflow::CX::V3::SecuritySettings::AudioExportSettings::AudioFormat
File format for exported audio file.
-
#enable_audio_redaction ⇒ ::Boolean
Enable audio redaction if it is true.
-
#gcs_bucket ⇒ ::String
Cloud Storage bucket to export audio record to.
-
#store_tts_audio ⇒ ::Boolean
Whether to store TTS audio.
Instance Attribute Details
#audio_export_pattern ⇒ ::String
Returns Filename pattern for exported audio. {conversation} and {timestamp} are placeholders that will be replaced with the conversation ID and epoch micros of the conversation. For example, "{conversation}/recording_{timestamp}.mulaw".
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/security_settings.rb', line 250 class AudioExportSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # File format for exported audio file. Currently only in telephony # recordings. module AudioFormat # Unspecified. Do not use. AUDIO_FORMAT_UNSPECIFIED = 0 # G.711 mu-law PCM with 8kHz sample rate. MULAW = 1 # MP3 file format. MP3 = 2 # OGG Vorbis. OGG = 3 end end |
#audio_format ⇒ ::Google::Cloud::Dialogflow::CX::V3::SecuritySettings::AudioExportSettings::AudioFormat
Returns File format for exported audio file. Currently only in telephony recordings.
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/security_settings.rb', line 250 class AudioExportSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # File format for exported audio file. Currently only in telephony # recordings. module AudioFormat # Unspecified. Do not use. AUDIO_FORMAT_UNSPECIFIED = 0 # G.711 mu-law PCM with 8kHz sample rate. MULAW = 1 # MP3 file format. MP3 = 2 # OGG Vorbis. OGG = 3 end end |
#enable_audio_redaction ⇒ ::Boolean
Returns Enable audio redaction if it is true. Note that this only redacts end-user audio data; Synthesised audio from the virtual agent is not redacted.
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/security_settings.rb', line 250 class AudioExportSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # File format for exported audio file. Currently only in telephony # recordings. module AudioFormat # Unspecified. Do not use. AUDIO_FORMAT_UNSPECIFIED = 0 # G.711 mu-law PCM with 8kHz sample rate. MULAW = 1 # MP3 file format. MP3 = 2 # OGG Vorbis. OGG = 3 end end |
#gcs_bucket ⇒ ::String
Returns Cloud Storage bucket to export audio record to. Setting this field would grant the Storage Object Creator role to the Dialogflow Service Agent. API caller that tries to modify this field should have the permission of storage.buckets.setIamPolicy.
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/security_settings.rb', line 250 class AudioExportSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # File format for exported audio file. Currently only in telephony # recordings. module AudioFormat # Unspecified. Do not use. AUDIO_FORMAT_UNSPECIFIED = 0 # G.711 mu-law PCM with 8kHz sample rate. MULAW = 1 # MP3 file format. MP3 = 2 # OGG Vorbis. OGG = 3 end end |
#store_tts_audio ⇒ ::Boolean
Returns Whether to store TTS audio. By default, TTS audio from the virtual agent is not exported.
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/security_settings.rb', line 250 class AudioExportSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # File format for exported audio file. Currently only in telephony # recordings. module AudioFormat # Unspecified. Do not use. AUDIO_FORMAT_UNSPECIFIED = 0 # G.711 mu-law PCM with 8kHz sample rate. MULAW = 1 # MP3 file format. MP3 = 2 # OGG Vorbis. OGG = 3 end end |