Class: Google::Cloud::Dialogflow::CX::V3::Tool::Authentication::ServiceAccountAuthConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/cx/v3/tool.rb

Overview

Configuration for authentication using a service account.

Instance Attribute Summary collapse

Instance Attribute Details

#service_account::String

Returns Required. The email address of the service account used to authenticate the tool call. Dialogflow uses this service account to exchange an access token and the access token is then sent in the Authorization header of the tool request.

The service account must have the roles/iam.serviceAccountTokenCreator role granted to the Dialogflow service agent.

Returns:

  • (::String)

    Required. The email address of the service account used to authenticate the tool call. Dialogflow uses this service account to exchange an access token and the access token is then sent in the Authorization header of the tool request.

    The service account must have the roles/iam.serviceAccountTokenCreator role granted to the Dialogflow service agent.



376
377
378
379
# File 'proto_docs/google/cloud/dialogflow/cx/v3/tool.rb', line 376

class ServiceAccountAuthConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end