Class: Google::Cloud::Dialogflow::CX::V3::Tool::Authentication::ServiceAgentAuthConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/cx/v3/tool.rb

Overview

Config for auth using Diglogflow service agent.

Defined Under Namespace

Modules: ServiceAgentAuth

Instance Attribute Summary collapse

Instance Attribute Details

#service_agent_auth::Google::Cloud::Dialogflow::CX::V3::Tool::Authentication::ServiceAgentAuthConfig::ServiceAgentAuth

Returns Optional. Indicate the auth token type generated from the Diglogflow service agent. The generated token is sent in the Authorization header.

Returns:



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
# File 'proto_docs/google/cloud/dialogflow/cx/v3/tool.rb', line 318

class ServiceAgentAuthConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Indicate the auth token type generated from the [Diglogflow service
  # agent](https://cloud.google.com/iam/docs/service-agents#dialogflow-service-agent).
  module ServiceAgentAuth
    # Service agent auth type unspecified. Default to ID_TOKEN.
    SERVICE_AGENT_AUTH_UNSPECIFIED = 0

    # Use [ID
    # token](https://cloud.google.com/docs/authentication/token-types#id)
    # generated from service agent. This can be used to access Cloud
    # Function and Cloud Run after you grant Invoker role to
    # `service-<PROJECT-NUMBER>@gcp-sa-dialogflow.iam.gserviceaccount.com`.
    ID_TOKEN = 1

    # Use [access
    # token](https://cloud.google.com/docs/authentication/token-types#access)
    # generated from service agent. This can be used to access other Google
    # Cloud APIs after you grant required roles to
    # `service-<PROJECT-NUMBER>@gcp-sa-dialogflow.iam.gserviceaccount.com`.
    ACCESS_TOKEN = 2
  end
end