Module: Google::Cloud::Dialogflow::CX::V3::Tool::Authentication::ServiceAgentAuthConfig::ServiceAgentAuth

Defined in:
proto_docs/google/cloud/dialogflow/cx/v3/tool.rb

Overview

Indicate the auth token type generated from the Diglogflow service agent.

Constant Summary collapse

SERVICE_AGENT_AUTH_UNSPECIFIED =

Service agent auth type unspecified. Default to ID_TOKEN.

0
ID_TOKEN =

Use ID token generated from service agent. This can be used to access Cloud Function and Cloud Run after you grant Invoker role to service-<PROJECT-NUMBER>@gcp-sa-dialogflow.iam.gserviceaccount.com.

1
ACCESS_TOKEN =

Use access token generated from service agent. This can be used to access other Google Cloud APIs after you grant required roles to service-<PROJECT-NUMBER>@gcp-sa-dialogflow.iam.gserviceaccount.com.

2