Class: Google::Cloud::Dialogflow::CX::V3::ToolUse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/cx/v3/trace.rb

Overview

Stores metadata of the invocation of an action supported by a tool.

Instance Attribute Summary collapse

Instance Attribute Details

#action::String

Returns Optional. Name of the action to be called during the tool use.

Returns:

  • (::String)

    Optional. Name of the action to be called during the tool use.



202
203
204
205
# File 'proto_docs/google/cloud/dialogflow/cx/v3/trace.rb', line 202

class ToolUse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#display_name::String (readonly)

Returns Output only. The display name of the tool.

Returns:

  • (::String)

    Output only. The display name of the tool.



202
203
204
205
# File 'proto_docs/google/cloud/dialogflow/cx/v3/trace.rb', line 202

class ToolUse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#input_action_parameters::Google::Protobuf::Struct

Returns Optional. A list of input parameters for the action.

Returns:



202
203
204
205
# File 'proto_docs/google/cloud/dialogflow/cx/v3/trace.rb', line 202

class ToolUse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#output_action_parameters::Google::Protobuf::Struct

Returns Optional. A list of output parameters generated by the action.

Returns:



202
203
204
205
# File 'proto_docs/google/cloud/dialogflow/cx/v3/trace.rb', line 202

class ToolUse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tool::String

Returns Required. The tool that should be used. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/tools/<ToolID>.

Returns:

  • (::String)

    Required. The tool that should be used. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/tools/<ToolID>.



202
203
204
205
# File 'proto_docs/google/cloud/dialogflow/cx/v3/trace.rb', line 202

class ToolUse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end