Class: Google::Cloud::Dialogflow::CX::V3::Tools::Rest::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb

Overview

REST client for the Tools service.

Service for managing Tools.

Defined Under Namespace

Classes: Configuration

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#agent_path, #secret_version_path, #service_path, #tool_path, #tool_version_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new Tools REST client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::Dialogflow::CX::V3::Tools::Rest::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::Dialogflow::CX::V3::Tools::Rest::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Tools client.

Yield Parameters:



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb', line 133

def initialize
  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end

  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @tools_stub = ::Google::Cloud::Dialogflow::CX::V3::Tools::Rest::ServiceStub.new(
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    credentials: credentials,
    logger: @config.logger
  )

  @tools_stub.logger(stub: true)&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end

  @location_client = Google::Cloud::Location::Locations::Rest::Client.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @tools_stub.endpoint
    config.universe_domain = @tools_stub.universe_domain
    config.bindings_override = @config.bindings_override
    config.logger = @tools_stub.logger if config.respond_to? :logger=
  end
end

Instance Attribute Details

#location_clientGoogle::Cloud::Location::Locations::Rest::Client (readonly)

Get the associated client for mix-in of the Locations.

Returns:

  • (Google::Cloud::Location::Locations::Rest::Client)


189
190
191
# File 'lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb', line 189

def location_client
  @location_client
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the Tools Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all Tools clients
::Google::Cloud::Dialogflow::CX::V3::Tools::Rest::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb', line 66

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "Dialogflow", "CX", "V3"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.timeout = 60.0
    default_config.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the Tools Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



103
104
105
106
# File 'lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb', line 103

def configure
  yield @config if block_given?
  @config
end

#create_tool(request, options = nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::Tool #create_tool(parent: nil, tool: nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::Tool

Creates a Tool in the specified agent.

Examples:

Basic example

require "google/cloud/dialogflow/cx/v3"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dialogflow::CX::V3::Tools::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dialogflow::CX::V3::CreateToolRequest.new

# Call the create_tool method.
result = client.create_tool request

# The returned object is of type Google::Cloud::Dialogflow::CX::V3::Tool.
p result

Overloads:

  • #create_tool(request, options = nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::Tool

    Pass arguments to create_tool via a request object, either of type CreateToolRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dialogflow::CX::V3::CreateToolRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #create_tool(parent: nil, tool: nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::Tool

    Pass arguments to create_tool via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The agent to create a Tool for. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>.

    • tool (::Google::Cloud::Dialogflow::CX::V3::Tool, ::Hash) (defaults to: nil)

      Required. The Tool to be created.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb', line 249

def create_tool request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dialogflow::CX::V3::CreateToolRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_tool..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dialogflow::CX::V3::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.create_tool.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_tool.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @tools_stub.create_tool request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#create_tool_version(request, options = nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::ToolVersion #create_tool_version(parent: nil, tool_version: nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::ToolVersion

Creates a version for the specified Tool.

Examples:

Basic example

require "google/cloud/dialogflow/cx/v3"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dialogflow::CX::V3::Tools::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dialogflow::CX::V3::CreateToolVersionRequest.new

# Call the create_tool_version method.
result = client.create_tool_version request

# The returned object is of type Google::Cloud::Dialogflow::CX::V3::ToolVersion.
p result

Overloads:

  • #create_tool_version(request, options = nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::ToolVersion

    Pass arguments to create_tool_version via a request object, either of type CreateToolVersionRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dialogflow::CX::V3::CreateToolVersionRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #create_tool_version(parent: nil, tool_version: nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::ToolVersion

    Pass arguments to create_tool_version via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The tool to create a version for. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/tools/<ToolID>.

    • tool_version (::Google::Cloud::Dialogflow::CX::V3::ToolVersion, ::Hash) (defaults to: nil)

      Required. The tool version to create.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
# File 'lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb', line 763

def create_tool_version request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dialogflow::CX::V3::CreateToolVersionRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_tool_version..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dialogflow::CX::V3::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.create_tool_version.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_tool_version.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @tools_stub.create_tool_version request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#delete_tool(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_tool(name: nil, force: nil) ⇒ ::Google::Protobuf::Empty

Deletes a specified Tool.

Examples:

Basic example

require "google/cloud/dialogflow/cx/v3"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dialogflow::CX::V3::Tools::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dialogflow::CX::V3::DeleteToolRequest.new

# Call the delete_tool method.
result = client.delete_tool request

# The returned object is of type Google::Protobuf::Empty.
p result

Overloads:

  • #delete_tool(request, options = nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_tool via a request object, either of type DeleteToolRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dialogflow::CX::V3::DeleteToolRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #delete_tool(name: nil, force: nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_tool via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the Tool to be deleted. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/tools/<ToolID>.

    • force (::Boolean) (defaults to: nil)

      This field has no effect for Tools not being used. For Tools that are used:

      • If force is set to false, an error will be returned with message indicating the referenced resources.
      • If force is set to true, Dialogflow will remove the tool, as well as any references to the tool.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
# File 'lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb', line 589

def delete_tool request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dialogflow::CX::V3::DeleteToolRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.delete_tool..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dialogflow::CX::V3::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.delete_tool.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.delete_tool.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @tools_stub.delete_tool request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#delete_tool_version(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_tool_version(name: nil, force: nil) ⇒ ::Google::Protobuf::Empty

Deletes the specified version of the Tool.

Examples:

Basic example

require "google/cloud/dialogflow/cx/v3"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dialogflow::CX::V3::Tools::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dialogflow::CX::V3::DeleteToolVersionRequest.new

# Call the delete_tool_version method.
result = client.delete_tool_version request

# The returned object is of type Google::Protobuf::Empty.
p result

Overloads:

  • #delete_tool_version(request, options = nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_tool_version via a request object, either of type DeleteToolVersionRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dialogflow::CX::V3::DeleteToolVersionRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #delete_tool_version(name: nil, force: nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_tool_version via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the tool version to delete. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/tools/<ToolID>/versions/<VersionID>.

    • force (::Boolean) (defaults to: nil)

      Optional. This field has no effect for Tools not being used. For Tools that are used:

      • If force is set to false, an error will be returned with message indicating the referenced resources.
      • If force is set to true, Dialogflow will remove the tool, as well as any references to the tool.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
# File 'lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb', line 933

def delete_tool_version request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dialogflow::CX::V3::DeleteToolVersionRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.delete_tool_version..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dialogflow::CX::V3::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.delete_tool_version.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.delete_tool_version.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @tools_stub.delete_tool_version request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_tool(request, options = nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::Tool #get_tool(name: nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::Tool

Retrieves the specified Tool.

Examples:

Basic example

require "google/cloud/dialogflow/cx/v3"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dialogflow::CX::V3::Tools::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dialogflow::CX::V3::GetToolRequest.new

# Call the get_tool method.
result = client.get_tool request

# The returned object is of type Google::Cloud::Dialogflow::CX::V3::Tool.
p result

Overloads:

  • #get_tool(request, options = nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::Tool

    Pass arguments to get_tool via a request object, either of type GetToolRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dialogflow::CX::V3::GetToolRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_tool(name: nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::Tool

    Pass arguments to get_tool via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the Tool. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/tools/<ToolID>.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
# File 'lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb', line 420

def get_tool request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dialogflow::CX::V3::GetToolRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_tool..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dialogflow::CX::V3::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_tool.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_tool.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @tools_stub.get_tool request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_tool_version(request, options = nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::ToolVersion #get_tool_version(name: nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::ToolVersion

Retrieves the specified version of the Tool.

Examples:

Basic example

require "google/cloud/dialogflow/cx/v3"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dialogflow::CX::V3::Tools::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dialogflow::CX::V3::GetToolVersionRequest.new

# Call the get_tool_version method.
result = client.get_tool_version request

# The returned object is of type Google::Cloud::Dialogflow::CX::V3::ToolVersion.
p result

Overloads:

  • #get_tool_version(request, options = nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::ToolVersion

    Pass arguments to get_tool_version via a request object, either of type GetToolVersionRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dialogflow::CX::V3::GetToolVersionRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_tool_version(name: nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::ToolVersion

    Pass arguments to get_tool_version via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the tool version. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/tools/<ToolID>/versions/<VersionID>.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
# File 'lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb', line 844

def get_tool_version request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dialogflow::CX::V3::GetToolVersionRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_tool_version..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dialogflow::CX::V3::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_tool_version.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_tool_version.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @tools_stub.get_tool_version request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_tool_versions(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dialogflow::CX::V3::ToolVersion> #list_tool_versions(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dialogflow::CX::V3::ToolVersion>

List versions of the specified Tool.

Examples:

Basic example

require "google/cloud/dialogflow/cx/v3"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dialogflow::CX::V3::Tools::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dialogflow::CX::V3::ListToolVersionsRequest.new

# Call the list_tool_versions method.
result = client.list_tool_versions request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::Dialogflow::CX::V3::ToolVersion.
  p item
end

Overloads:

  • #list_tool_versions(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dialogflow::CX::V3::ToolVersion>

    Pass arguments to list_tool_versions via a request object, either of type ListToolVersionsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dialogflow::CX::V3::ListToolVersionsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #list_tool_versions(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dialogflow::CX::V3::ToolVersion>

    Pass arguments to list_tool_versions via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent of the tool versions. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/tools/<ToolID>.

    • page_size (::Integer) (defaults to: nil)

      Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.

    • page_token (::String) (defaults to: nil)

      Optional. The next_page_token value returned from a previous list request.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
# File 'lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb', line 678

def list_tool_versions request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dialogflow::CX::V3::ListToolVersionsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_tool_versions..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dialogflow::CX::V3::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_tool_versions.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_tool_versions.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @tools_stub.list_tool_versions request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @tools_stub, :list_tool_versions, "tool_versions", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_tools(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dialogflow::CX::V3::Tool> #list_tools(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dialogflow::CX::V3::Tool>

Returns a list of Tools in the specified agent.

Examples:

Basic example

require "google/cloud/dialogflow/cx/v3"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dialogflow::CX::V3::Tools::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dialogflow::CX::V3::ListToolsRequest.new

# Call the list_tools method.
result = client.list_tools request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::Dialogflow::CX::V3::Tool.
  p item
end

Overloads:

  • #list_tools(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dialogflow::CX::V3::Tool>

    Pass arguments to list_tools via a request object, either of type ListToolsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dialogflow::CX::V3::ListToolsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #list_tools(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dialogflow::CX::V3::Tool>

    Pass arguments to list_tools via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The agent to list the Tools from. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>.

    • page_size (::Integer) (defaults to: nil)

      The maximum number of items to return in a single page. By default 100 and at most 1000.

    • page_token (::String) (defaults to: nil)

      The next_page_token value returned from a previous list request.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb', line 338

def list_tools request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dialogflow::CX::V3::ListToolsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_tools..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dialogflow::CX::V3::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_tools.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_tools.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @tools_stub.list_tools request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @tools_stub, :list_tools, "tools", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


196
197
198
# File 'lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb', line 196

def logger
  @tools_stub.logger
end

#restore_tool_version(request, options = nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::RestoreToolVersionResponse #restore_tool_version(name: nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::RestoreToolVersionResponse

Retrieves the specified version of the Tool and stores it as the current tool draft, returning the tool with resources updated.

Examples:

Basic example

require "google/cloud/dialogflow/cx/v3"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dialogflow::CX::V3::Tools::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dialogflow::CX::V3::RestoreToolVersionRequest.new

# Call the restore_tool_version method.
result = client.restore_tool_version request

# The returned object is of type Google::Cloud::Dialogflow::CX::V3::RestoreToolVersionResponse.
p result

Overloads:

  • #restore_tool_version(request, options = nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::RestoreToolVersionResponse

    Pass arguments to restore_tool_version via a request object, either of type RestoreToolVersionRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dialogflow::CX::V3::RestoreToolVersionRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #restore_tool_version(name: nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::RestoreToolVersionResponse

    Pass arguments to restore_tool_version via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the tool version. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/tools/<ToolID>/versions/<VersionID>.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
# File 'lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb', line 1014

def restore_tool_version request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dialogflow::CX::V3::RestoreToolVersionRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.restore_tool_version..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dialogflow::CX::V3::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.restore_tool_version.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.restore_tool_version.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @tools_stub.restore_tool_version request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


113
114
115
# File 'lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb', line 113

def universe_domain
  @tools_stub.universe_domain
end

#update_tool(request, options = nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::Tool #update_tool(tool: nil, update_mask: nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::Tool

Update the specified Tool.

Examples:

Basic example

require "google/cloud/dialogflow/cx/v3"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dialogflow::CX::V3::Tools::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dialogflow::CX::V3::UpdateToolRequest.new

# Call the update_tool method.
result = client.update_tool request

# The returned object is of type Google::Cloud::Dialogflow::CX::V3::Tool.
p result

Overloads:

  • #update_tool(request, options = nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::Tool

    Pass arguments to update_tool via a request object, either of type UpdateToolRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dialogflow::CX::V3::UpdateToolRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #update_tool(tool: nil, update_mask: nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::Tool

    Pass arguments to update_tool via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
# File 'lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb', line 501

def update_tool request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dialogflow::CX::V3::UpdateToolRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_tool..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dialogflow::CX::V3::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.update_tool.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_tool.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @tools_stub.update_tool request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end