Class: Google::Cloud::Dialogflow::CX::V3::UpdateExampleRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/cx/v3/example.rb

Overview

The request message for Examples.UpdateExample.

Instance Attribute Summary collapse

Instance Attribute Details

#example::Google::Cloud::Dialogflow::CX::V3::Example

Returns Required. The example to update.

Returns:



115
116
117
118
# File 'proto_docs/google/cloud/dialogflow/cx/v3/example.rb', line 115

class UpdateExampleRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns Optional. The mask to control which fields get updated. If the mask is not present, all fields will be updated.

Returns:

  • (::Google::Protobuf::FieldMask)

    Optional. The mask to control which fields get updated. If the mask is not present, all fields will be updated.



115
116
117
118
# File 'proto_docs/google/cloud/dialogflow/cx/v3/example.rb', line 115

class UpdateExampleRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end