Class: Google::Cloud::Dialogflow::CX::V3::UpdatePlaybookRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::CX::V3::UpdatePlaybookRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb
Overview
The request message for Playbooks.UpdatePlaybook.
Instance Attribute Summary collapse
-
#playbook ⇒ ::Google::Cloud::Dialogflow::CX::V3::Playbook
Required.
-
#update_mask ⇒ ::Google::Protobuf::FieldMask
The mask to control which fields get updated.
Instance Attribute Details
#playbook ⇒ ::Google::Cloud::Dialogflow::CX::V3::Playbook
Returns Required. The playbook to update.
105 106 107 108 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 105 class UpdatePlaybookRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_mask ⇒ ::Google::Protobuf::FieldMask
Returns The mask to control which fields get updated. If the mask is not present, all fields will be updated.
105 106 107 108 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 105 class UpdatePlaybookRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |