Class: Google::Cloud::Dialogflow::CX::V3::UpdateToolRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::CX::V3::UpdateToolRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/cx/v3/tool.rb
Overview
The request message for Tools.UpdateTool.
Instance Attribute Summary collapse
-
#tool ⇒ ::Google::Cloud::Dialogflow::CX::V3::Tool
Required.
-
#update_mask ⇒ ::Google::Protobuf::FieldMask
The mask to control which fields get updated.
Instance Attribute Details
#tool ⇒ ::Google::Cloud::Dialogflow::CX::V3::Tool
Returns Required. The Tool to be updated.
93 94 95 96 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/tool.rb', line 93 class UpdateToolRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_mask ⇒ ::Google::Protobuf::FieldMask
Returns The mask to control which fields get updated. If the mask is not present, all fields will be updated.
93 94 95 96 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/tool.rb', line 93 class UpdateToolRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |