Class: Google::Cloud::Dialogflow::CX::V3::WebhookRequest::IntentInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/cx/v3/webhook.rb

Overview

Represents intent information communicated to the webhook.

Defined Under Namespace

Classes: IntentParameterValue, ParametersEntry

Instance Attribute Summary collapse

Instance Attribute Details

#confidence::Float

Returns The confidence of the matched intent. Values range from 0.0 (completely uncertain) to 1.0 (completely certain).

Returns:

  • (::Float)

    The confidence of the matched intent. Values range from 0.0 (completely uncertain) to 1.0 (completely certain).



518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
# File 'proto_docs/google/cloud/dialogflow/cx/v3/webhook.rb', line 518

class IntentInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a value for an intent parameter.
  # @!attribute [rw] original_value
  #   @return [::String]
  #     Always present. Original text value extracted from user utterance.
  # @!attribute [rw] resolved_value
  #   @return [::Google::Protobuf::Value]
  #     Always present. Structured value for the parameter extracted from user
  #     utterance.
  class IntentParameterValue
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dialogflow::CX::V3::WebhookRequest::IntentInfo::IntentParameterValue]
  class ParametersEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#display_name::String

Returns Always present. The display name of the last matched intent.

Returns:

  • (::String)

    Always present. The display name of the last matched intent.



518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
# File 'proto_docs/google/cloud/dialogflow/cx/v3/webhook.rb', line 518

class IntentInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a value for an intent parameter.
  # @!attribute [rw] original_value
  #   @return [::String]
  #     Always present. Original text value extracted from user utterance.
  # @!attribute [rw] resolved_value
  #   @return [::Google::Protobuf::Value]
  #     Always present. Structured value for the parameter extracted from user
  #     utterance.
  class IntentParameterValue
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dialogflow::CX::V3::WebhookRequest::IntentInfo::IntentParameterValue]
  class ParametersEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#last_matched_intent::String

Returns Always present. The unique identifier of the last matched intent. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/intents/<IntentID>.

Returns:

  • (::String)

    Always present. The unique identifier of the last matched intent. Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/intents/<IntentID>.



518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
# File 'proto_docs/google/cloud/dialogflow/cx/v3/webhook.rb', line 518

class IntentInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a value for an intent parameter.
  # @!attribute [rw] original_value
  #   @return [::String]
  #     Always present. Original text value extracted from user utterance.
  # @!attribute [rw] resolved_value
  #   @return [::Google::Protobuf::Value]
  #     Always present. Structured value for the parameter extracted from user
  #     utterance.
  class IntentParameterValue
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dialogflow::CX::V3::WebhookRequest::IntentInfo::IntentParameterValue]
  class ParametersEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#parameters::Google::Protobuf::Map{::String => ::Google::Cloud::Dialogflow::CX::V3::WebhookRequest::IntentInfo::IntentParameterValue}

Returns Parameters identified as a result of intent matching. This is a map of the name of the identified parameter to the value of the parameter identified from the user's utterance. All parameters defined in the matched intent that are identified will be surfaced here.

Returns:



518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
# File 'proto_docs/google/cloud/dialogflow/cx/v3/webhook.rb', line 518

class IntentInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a value for an intent parameter.
  # @!attribute [rw] original_value
  #   @return [::String]
  #     Always present. Original text value extracted from user utterance.
  # @!attribute [rw] resolved_value
  #   @return [::Google::Protobuf::Value]
  #     Always present. Structured value for the parameter extracted from user
  #     utterance.
  class IntentParameterValue
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dialogflow::CX::V3::WebhookRequest::IntentInfo::IntentParameterValue]
  class ParametersEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end