Class: Google::Cloud::Dialogflow::CX::V3::WebhookResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::CX::V3::WebhookResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/cx/v3/webhook.rb
Overview
The response message for a webhook call.
Defined Under Namespace
Classes: FulfillmentResponse
Instance Attribute Summary collapse
-
#fulfillment_response ⇒ ::Google::Cloud::Dialogflow::CX::V3::WebhookResponse::FulfillmentResponse
The fulfillment response to send to the user.
-
#page_info ⇒ ::Google::Cloud::Dialogflow::CX::V3::PageInfo
Information about page status.
-
#payload ⇒ ::Google::Protobuf::Struct
Value to append directly to QueryResult.webhook_payloads.
-
#session_info ⇒ ::Google::Cloud::Dialogflow::CX::V3::SessionInfo
Information about session status.
-
#target_flow ⇒ ::String
The target flow to transition to.
-
#target_page ⇒ ::String
The target page to transition to.
Instance Attribute Details
#fulfillment_response ⇒ ::Google::Cloud::Dialogflow::CX::V3::WebhookResponse::FulfillmentResponse
Returns The fulfillment response to send to the user. This field can be omitted by the webhook if it does not intend to send any response to the user.
592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/webhook.rb', line 592 class WebhookResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a fulfillment response to the user. # @!attribute [rw] messages # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::ResponseMessage>] # The list of rich message responses to present to the user. # @!attribute [rw] merge_behavior # @return [::Google::Cloud::Dialogflow::CX::V3::WebhookResponse::FulfillmentResponse::MergeBehavior] # Merge behavior for `messages`. class FulfillmentResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines merge behavior for `messages`. module MergeBehavior # Not specified. `APPEND` will be used. MERGE_BEHAVIOR_UNSPECIFIED = 0 # `messages` will be appended to the list of messages waiting to be sent # to the user. APPEND = 1 # `messages` will replace the list of messages waiting to be sent to the # user. REPLACE = 2 end end end |
#page_info ⇒ ::Google::Cloud::Dialogflow::CX::V3::PageInfo
Returns Information about page status. This field can be omitted by the webhook if it does not intend to modify page status.
592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/webhook.rb', line 592 class WebhookResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a fulfillment response to the user. # @!attribute [rw] messages # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::ResponseMessage>] # The list of rich message responses to present to the user. # @!attribute [rw] merge_behavior # @return [::Google::Cloud::Dialogflow::CX::V3::WebhookResponse::FulfillmentResponse::MergeBehavior] # Merge behavior for `messages`. class FulfillmentResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines merge behavior for `messages`. module MergeBehavior # Not specified. `APPEND` will be used. MERGE_BEHAVIOR_UNSPECIFIED = 0 # `messages` will be appended to the list of messages waiting to be sent # to the user. APPEND = 1 # `messages` will replace the list of messages waiting to be sent to the # user. REPLACE = 2 end end end |
#payload ⇒ ::Google::Protobuf::Struct
Returns Value to append directly to QueryResult.webhook_payloads.
592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/webhook.rb', line 592 class WebhookResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a fulfillment response to the user. # @!attribute [rw] messages # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::ResponseMessage>] # The list of rich message responses to present to the user. # @!attribute [rw] merge_behavior # @return [::Google::Cloud::Dialogflow::CX::V3::WebhookResponse::FulfillmentResponse::MergeBehavior] # Merge behavior for `messages`. class FulfillmentResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines merge behavior for `messages`. module MergeBehavior # Not specified. `APPEND` will be used. MERGE_BEHAVIOR_UNSPECIFIED = 0 # `messages` will be appended to the list of messages waiting to be sent # to the user. APPEND = 1 # `messages` will replace the list of messages waiting to be sent to the # user. REPLACE = 2 end end end |
#session_info ⇒ ::Google::Cloud::Dialogflow::CX::V3::SessionInfo
Returns Information about session status. This field can be omitted by the webhook if it does not intend to modify session status.
592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/webhook.rb', line 592 class WebhookResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a fulfillment response to the user. # @!attribute [rw] messages # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::ResponseMessage>] # The list of rich message responses to present to the user. # @!attribute [rw] merge_behavior # @return [::Google::Cloud::Dialogflow::CX::V3::WebhookResponse::FulfillmentResponse::MergeBehavior] # Merge behavior for `messages`. class FulfillmentResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines merge behavior for `messages`. module MergeBehavior # Not specified. `APPEND` will be used. MERGE_BEHAVIOR_UNSPECIFIED = 0 # `messages` will be appended to the list of messages waiting to be sent # to the user. APPEND = 1 # `messages` will replace the list of messages waiting to be sent to the # user. REPLACE = 2 end end end |
#target_flow ⇒ ::String
Returns The target flow to transition to.
Format:
projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/flows/<FlowID>.
Note: The following fields are mutually exclusive: target_flow, target_page. If a field in that set is populated, all other fields in the set will automatically be cleared.
592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/webhook.rb', line 592 class WebhookResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a fulfillment response to the user. # @!attribute [rw] messages # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::ResponseMessage>] # The list of rich message responses to present to the user. # @!attribute [rw] merge_behavior # @return [::Google::Cloud::Dialogflow::CX::V3::WebhookResponse::FulfillmentResponse::MergeBehavior] # Merge behavior for `messages`. class FulfillmentResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines merge behavior for `messages`. module MergeBehavior # Not specified. `APPEND` will be used. MERGE_BEHAVIOR_UNSPECIFIED = 0 # `messages` will be appended to the list of messages waiting to be sent # to the user. APPEND = 1 # `messages` will replace the list of messages waiting to be sent to the # user. REPLACE = 2 end end end |
#target_page ⇒ ::String
Returns The target page to transition to.
Format:
projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/flows/<FlowID>/pages/<PageID>.
Note: The following fields are mutually exclusive: target_page, target_flow. If a field in that set is populated, all other fields in the set will automatically be cleared.
592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/webhook.rb', line 592 class WebhookResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a fulfillment response to the user. # @!attribute [rw] messages # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::ResponseMessage>] # The list of rich message responses to present to the user. # @!attribute [rw] merge_behavior # @return [::Google::Cloud::Dialogflow::CX::V3::WebhookResponse::FulfillmentResponse::MergeBehavior] # Merge behavior for `messages`. class FulfillmentResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines merge behavior for `messages`. module MergeBehavior # Not specified. `APPEND` will be used. MERGE_BEHAVIOR_UNSPECIFIED = 0 # `messages` will be appended to the list of messages waiting to be sent # to the user. APPEND = 1 # `messages` will replace the list of messages waiting to be sent to the # user. REPLACE = 2 end end end |