Class: Google::Cloud::Dialogflow::CX::V3::Action
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::CX::V3::Action
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/cx/v3/trace.rb
Overview
Action performed by end user or Dialogflow agent in the conversation.
Instance Attribute Summary collapse
-
#agent_utterance ⇒ ::Google::Cloud::Dialogflow::CX::V3::AgentUtterance
Optional.
-
#flow_invocation ⇒ ::Google::Cloud::Dialogflow::CX::V3::FlowInvocation
Optional.
-
#flow_transition ⇒ ::Google::Cloud::Dialogflow::CX::V3::FlowTransition
Optional.
-
#playbook_invocation ⇒ ::Google::Cloud::Dialogflow::CX::V3::PlaybookInvocation
Optional.
-
#playbook_transition ⇒ ::Google::Cloud::Dialogflow::CX::V3::PlaybookTransition
Optional.
-
#tool_use ⇒ ::Google::Cloud::Dialogflow::CX::V3::ToolUse
Optional.
-
#user_utterance ⇒ ::Google::Cloud::Dialogflow::CX::V3::UserUtterance
Optional.
Instance Attribute Details
#agent_utterance ⇒ ::Google::Cloud::Dialogflow::CX::V3::AgentUtterance
Returns Optional. Action performed by the agent as a message.
Note: The following fields are mutually exclusive: agent_utterance, user_utterance, tool_use, playbook_invocation, flow_invocation, playbook_transition, flow_transition. If a field in that set is populated, all other fields in the set will automatically be cleared.
161 162 163 164 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/trace.rb', line 161 class Action include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#flow_invocation ⇒ ::Google::Cloud::Dialogflow::CX::V3::FlowInvocation
Returns Optional. Action performed on behalf of the agent by invoking a CX flow.
Note: The following fields are mutually exclusive: flow_invocation, user_utterance, agent_utterance, tool_use, playbook_invocation, playbook_transition, flow_transition. If a field in that set is populated, all other fields in the set will automatically be cleared.
161 162 163 164 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/trace.rb', line 161 class Action include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#flow_transition ⇒ ::Google::Cloud::Dialogflow::CX::V3::FlowTransition
Returns Optional. Action performed on behalf of the agent by transitioning to a target CX flow.
Note: The following fields are mutually exclusive: flow_transition, user_utterance, agent_utterance, tool_use, playbook_invocation, flow_invocation, playbook_transition. If a field in that set is populated, all other fields in the set will automatically be cleared.
161 162 163 164 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/trace.rb', line 161 class Action include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#playbook_invocation ⇒ ::Google::Cloud::Dialogflow::CX::V3::PlaybookInvocation
Returns Optional. Action performed on behalf of the agent by invoking a child playbook.
Note: The following fields are mutually exclusive: playbook_invocation, user_utterance, agent_utterance, tool_use, flow_invocation, playbook_transition, flow_transition. If a field in that set is populated, all other fields in the set will automatically be cleared.
161 162 163 164 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/trace.rb', line 161 class Action include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#playbook_transition ⇒ ::Google::Cloud::Dialogflow::CX::V3::PlaybookTransition
Returns Optional. Action performed on behalf of the agent by transitioning to a target playbook.
Note: The following fields are mutually exclusive: playbook_transition, user_utterance, agent_utterance, tool_use, playbook_invocation, flow_invocation, flow_transition. If a field in that set is populated, all other fields in the set will automatically be cleared.
161 162 163 164 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/trace.rb', line 161 class Action include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tool_use ⇒ ::Google::Cloud::Dialogflow::CX::V3::ToolUse
Returns Optional. Action performed on behalf of the agent by calling a plugin tool.
Note: The following fields are mutually exclusive: tool_use, user_utterance, agent_utterance, playbook_invocation, flow_invocation, playbook_transition, flow_transition. If a field in that set is populated, all other fields in the set will automatically be cleared.
161 162 163 164 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/trace.rb', line 161 class Action include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#user_utterance ⇒ ::Google::Cloud::Dialogflow::CX::V3::UserUtterance
Returns Optional. Agent obtained a message from the customer.
Note: The following fields are mutually exclusive: user_utterance, agent_utterance, tool_use, playbook_invocation, flow_invocation, playbook_transition, flow_transition. If a field in that set is populated, all other fields in the set will automatically be cleared.
161 162 163 164 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/trace.rb', line 161 class Action include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |