Class: Google::Cloud::Dialogflow::CX::V3::ExportPlaybookRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::CX::V3::ExportPlaybookRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb
Overview
The request message for Playbooks.ExportPlaybook.
Defined Under Namespace
Modules: DataFormat
Instance Attribute Summary collapse
-
#data_format ⇒ ::Google::Cloud::Dialogflow::CX::V3::ExportPlaybookRequest::DataFormat
Optional.
-
#name ⇒ ::String
Required.
-
#playbook_uri ⇒ ::String
Optional.
Instance Attribute Details
#data_format ⇒ ::Google::Cloud::Dialogflow::CX::V3::ExportPlaybookRequest::DataFormat
Returns Optional. The data format of the exported agent. If not specified, BLOB
is assumed.
369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 369 class ExportPlaybookRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Data format of the exported playbook. module DataFormat # Unspecified format. DATA_FORMAT_UNSPECIFIED = 0 # Flow content will be exported as raw bytes. BLOB = 1 # Flow content will be exported in JSON format. JSON = 2 end end |
#name ⇒ ::String
Returns Required. The name of the playbook to export.
Format:
projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>.
369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 369 class ExportPlaybookRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Data format of the exported playbook. module DataFormat # Unspecified format. DATA_FORMAT_UNSPECIFIED = 0 # Flow content will be exported as raw bytes. BLOB = 1 # Flow content will be exported in JSON format. JSON = 2 end end |
#playbook_uri ⇒ ::String
Returns Optional. The Google Cloud
Storage URI to export the playbook
to. The format of this URI must be gs://<bucket-name>/<object-name>. If
left unspecified, the serialized playbook is returned inline.
Dialogflow performs a write operation for the Cloud Storage object on the caller's behalf, so your request authentication must have write permissions for the object. For more information, see Dialogflow access control.
369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 369 class ExportPlaybookRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Data format of the exported playbook. module DataFormat # Unspecified format. DATA_FORMAT_UNSPECIFIED = 0 # Flow content will be exported as raw bytes. BLOB = 1 # Flow content will be exported in JSON format. JSON = 2 end end |