Class: Google::Cloud::Dialogflow::CX::V3::Handler
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::CX::V3::Handler
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb
Overview
Handler can be used to define custom logic to be executed based on the user-specified triggers.
Defined Under Namespace
Classes: EventHandler, LifecycleHandler
Instance Attribute Summary collapse
-
#event_handler ⇒ ::Google::Cloud::Dialogflow::CX::V3::Handler::EventHandler
A handler triggered by event.
-
#lifecycle_handler ⇒ ::Google::Cloud::Dialogflow::CX::V3::Handler::LifecycleHandler
A handler triggered during specific lifecycle of the playbook execution.
Instance Attribute Details
#event_handler ⇒ ::Google::Cloud::Dialogflow::CX::V3::Handler::EventHandler
Returns A handler triggered by event.
Note: The following fields are mutually exclusive: event_handler, lifecycle_handler. If a field in that set is populated, all other fields in the set will automatically be cleared.
501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 501 class Handler include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A handler that is triggered by the specified # {::Google::Cloud::Dialogflow::CX::V3::Handler::EventHandler#event event}. # @!attribute [rw] event # @return [::String] # Required. The name of the event that triggers this handler. # @!attribute [rw] condition # @return [::String] # Optional. The condition that must be satisfied to trigger this handler. # @!attribute [rw] fulfillment # @return [::Google::Cloud::Dialogflow::CX::V3::Fulfillment] # Required. The fulfillment to call when the event occurs. class EventHandler include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A handler that is triggered on the specific # {::Google::Cloud::Dialogflow::CX::V3::Handler::LifecycleHandler#lifecycle_stage lifecycle_stage} # of the playbook execution. # @!attribute [rw] lifecycle_stage # @return [::String] # Required. The name of the lifecycle stage that triggers this handler. # Supported values: # * `playbook-start` # * `pre-action-selection` # * `pre-action-execution` # @!attribute [rw] condition # @return [::String] # Optional. The condition that must be satisfied to trigger this handler. # @!attribute [rw] fulfillment # @return [::Google::Cloud::Dialogflow::CX::V3::Fulfillment] # Required. The fulfillment to call when this handler is triggered. class LifecycleHandler include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#lifecycle_handler ⇒ ::Google::Cloud::Dialogflow::CX::V3::Handler::LifecycleHandler
Returns A handler triggered during specific lifecycle of the playbook execution.
Note: The following fields are mutually exclusive: lifecycle_handler, event_handler. If a field in that set is populated, all other fields in the set will automatically be cleared.
501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 501 class Handler include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A handler that is triggered by the specified # {::Google::Cloud::Dialogflow::CX::V3::Handler::EventHandler#event event}. # @!attribute [rw] event # @return [::String] # Required. The name of the event that triggers this handler. # @!attribute [rw] condition # @return [::String] # Optional. The condition that must be satisfied to trigger this handler. # @!attribute [rw] fulfillment # @return [::Google::Cloud::Dialogflow::CX::V3::Fulfillment] # Required. The fulfillment to call when the event occurs. class EventHandler include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A handler that is triggered on the specific # {::Google::Cloud::Dialogflow::CX::V3::Handler::LifecycleHandler#lifecycle_stage lifecycle_stage} # of the playbook execution. # @!attribute [rw] lifecycle_stage # @return [::String] # Required. The name of the lifecycle stage that triggers this handler. # Supported values: # * `playbook-start` # * `pre-action-selection` # * `pre-action-execution` # @!attribute [rw] condition # @return [::String] # Optional. The condition that must be satisfied to trigger this handler. # @!attribute [rw] fulfillment # @return [::Google::Cloud::Dialogflow::CX::V3::Fulfillment] # Required. The fulfillment to call when this handler is triggered. class LifecycleHandler include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |