Class: Google::Cloud::Dialogflow::CX::V3::Handler::EventHandler
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::CX::V3::Handler::EventHandler
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb
Overview
A handler that is triggered by the specified event.
Instance Attribute Summary collapse
-
#condition ⇒ ::String
Optional.
-
#event ⇒ ::String
Required.
-
#fulfillment ⇒ ::Google::Cloud::Dialogflow::CX::V3::Fulfillment
Required.
Instance Attribute Details
#condition ⇒ ::String
Returns Optional. The condition that must be satisfied to trigger this handler.
516 517 518 519 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 516 class EventHandler include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#event ⇒ ::String
Returns Required. The name of the event that triggers this handler.
516 517 518 519 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 516 class EventHandler include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#fulfillment ⇒ ::Google::Cloud::Dialogflow::CX::V3::Fulfillment
Returns Required. The fulfillment to call when the event occurs.
516 517 518 519 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 516 class EventHandler include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |