Class: Google::Cloud::Dialogflow::CX::V3::Handler::LifecycleHandler
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::CX::V3::Handler::LifecycleHandler
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb
Overview
A handler that is triggered on the specific lifecycle_stage of the playbook execution.
Instance Attribute Summary collapse
-
#condition ⇒ ::String
Optional.
-
#fulfillment ⇒ ::Google::Cloud::Dialogflow::CX::V3::Fulfillment
Required.
-
#lifecycle_stage ⇒ ::String
Required.
Instance Attribute Details
#condition ⇒ ::String
Returns Optional. The condition that must be satisfied to trigger this handler.
537 538 539 540 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 537 class LifecycleHandler include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#fulfillment ⇒ ::Google::Cloud::Dialogflow::CX::V3::Fulfillment
Returns Required. The fulfillment to call when this handler is triggered.
537 538 539 540 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 537 class LifecycleHandler include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#lifecycle_stage ⇒ ::String
Returns Required. The name of the lifecycle stage that triggers this handler. Supported values:
playbook-startpre-action-selectionpre-action-execution.
537 538 539 540 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 537 class LifecycleHandler include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |