Class: Google::Cloud::Dialogflow::CX::V3::ImportPlaybookRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::CX::V3::ImportPlaybookRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb
Overview
The request message for Playbooks.ImportPlaybook.
Instance Attribute Summary collapse
-
#import_strategy ⇒ ::Google::Cloud::Dialogflow::CX::V3::PlaybookImportStrategy
Optional.
-
#parent ⇒ ::String
Required.
-
#playbook_content ⇒ ::String
Uncompressed raw byte content for playbook.
- #playbook_uri ⇒ ::String
Instance Attribute Details
#import_strategy ⇒ ::Google::Cloud::Dialogflow::CX::V3::PlaybookImportStrategy
Returns Optional. Specifies the import strategy used when resolving resource conflicts.
408 409 410 411 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 408 class ImportPlaybookRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The agent to import the playbook into.
Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>.
408 409 410 411 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 408 class ImportPlaybookRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#playbook_content ⇒ ::String
Returns Uncompressed raw byte content for playbook.
Note: The following fields are mutually exclusive: playbook_content, playbook_uri. If a field in that set is populated, all other fields in the set will automatically be cleared.
408 409 410 411 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 408 class ImportPlaybookRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#playbook_uri ⇒ ::String
Returns Dialogflow access control.
Note: The following fields are mutually exclusive: playbook_uri, playbook_content. If a field in that set is populated, all other fields in the set will automatically be cleared.
408 409 410 411 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 408 class ImportPlaybookRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |