Class: Google::Cloud::Dialogflow::CX::V3::Match
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::CX::V3::Match
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/cx/v3/session.rb
Overview
Represents one match result of [MatchIntent][].
Defined Under Namespace
Modules: MatchType
Instance Attribute Summary collapse
-
#confidence ⇒ ::Float
The confidence of this match.
-
#event ⇒ ::String
The event that matched the query.
-
#intent ⇒ ::Google::Cloud::Dialogflow::CX::V3::Intent
The Intent that matched the query.
-
#match_type ⇒ ::Google::Cloud::Dialogflow::CX::V3::Match::MatchType
Type of this Match.
-
#parameters ⇒ ::Google::Protobuf::Struct
The collection of parameters extracted from the query.
-
#resolved_input ⇒ ::String
Final text input which was matched during MatchIntent.
Instance Attribute Details
#confidence ⇒ ::Float
Returns The confidence of this match. Values range from 0.0 (completely uncertain) to 1.0 (completely certain). This value is for informational purpose only and is only used to help match the best intent within the classification threshold. This value may change for the same end-user expression at any time due to a model retraining or change in implementation.
1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 1197 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/session.rb', line 1163 class Match include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of a Match. module MatchType # Not specified. Should never be used. MATCH_TYPE_UNSPECIFIED = 0 # The query was matched to an intent. INTENT = 1 # The query directly triggered an intent. DIRECT_INTENT = 2 # The query was used for parameter filling. PARAMETER_FILLING = 3 # No match was found for the query. NO_MATCH = 4 # Indicates an empty query. NO_INPUT = 5 # The query directly triggered an event. EVENT = 6 # The query was matched to a Knowledge Connector answer. KNOWLEDGE_CONNECTOR = 8 # The query was handled by a # {::Google::Cloud::Dialogflow::CX::V3::Playbook `Playbook`}. PLAYBOOK = 9 end end |
#event ⇒ ::String
1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 1197 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/session.rb', line 1163 class Match include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of a Match. module MatchType # Not specified. Should never be used. MATCH_TYPE_UNSPECIFIED = 0 # The query was matched to an intent. INTENT = 1 # The query directly triggered an intent. DIRECT_INTENT = 2 # The query was used for parameter filling. PARAMETER_FILLING = 3 # No match was found for the query. NO_MATCH = 4 # Indicates an empty query. NO_INPUT = 5 # The query directly triggered an event. EVENT = 6 # The query was matched to a Knowledge Connector answer. KNOWLEDGE_CONNECTOR = 8 # The query was handled by a # {::Google::Cloud::Dialogflow::CX::V3::Playbook `Playbook`}. PLAYBOOK = 9 end end |
#intent ⇒ ::Google::Cloud::Dialogflow::CX::V3::Intent
1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 1197 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/session.rb', line 1163 class Match include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of a Match. module MatchType # Not specified. Should never be used. MATCH_TYPE_UNSPECIFIED = 0 # The query was matched to an intent. INTENT = 1 # The query directly triggered an intent. DIRECT_INTENT = 2 # The query was used for parameter filling. PARAMETER_FILLING = 3 # No match was found for the query. NO_MATCH = 4 # Indicates an empty query. NO_INPUT = 5 # The query directly triggered an event. EVENT = 6 # The query was matched to a Knowledge Connector answer. KNOWLEDGE_CONNECTOR = 8 # The query was handled by a # {::Google::Cloud::Dialogflow::CX::V3::Playbook `Playbook`}. PLAYBOOK = 9 end end |
#match_type ⇒ ::Google::Cloud::Dialogflow::CX::V3::Match::MatchType
Returns Type of this Match.
1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 1197 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/session.rb', line 1163 class Match include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of a Match. module MatchType # Not specified. Should never be used. MATCH_TYPE_UNSPECIFIED = 0 # The query was matched to an intent. INTENT = 1 # The query directly triggered an intent. DIRECT_INTENT = 2 # The query was used for parameter filling. PARAMETER_FILLING = 3 # No match was found for the query. NO_MATCH = 4 # Indicates an empty query. NO_INPUT = 5 # The query directly triggered an event. EVENT = 6 # The query was matched to a Knowledge Connector answer. KNOWLEDGE_CONNECTOR = 8 # The query was handled by a # {::Google::Cloud::Dialogflow::CX::V3::Playbook `Playbook`}. PLAYBOOK = 9 end end |
#parameters ⇒ ::Google::Protobuf::Struct
Returns The collection of parameters extracted from the query.
Depending on your protocol or client library language, this is a map, associative array, symbol table, dictionary, or JSON object composed of a collection of (MapKey, MapValue) pairs:
- MapKey type: string
- MapKey value: parameter name
- MapValue type: If parameter's entity type is a composite entity then use map, otherwise, depending on the parameter value type, it could be one of string, number, boolean, null, list or map.
- MapValue value: If parameter's entity type is a composite entity then use map from composite entity property names to property values, otherwise, use parameter value.
1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 1197 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/session.rb', line 1163 class Match include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of a Match. module MatchType # Not specified. Should never be used. MATCH_TYPE_UNSPECIFIED = 0 # The query was matched to an intent. INTENT = 1 # The query directly triggered an intent. DIRECT_INTENT = 2 # The query was used for parameter filling. PARAMETER_FILLING = 3 # No match was found for the query. NO_MATCH = 4 # Indicates an empty query. NO_INPUT = 5 # The query directly triggered an event. EVENT = 6 # The query was matched to a Knowledge Connector answer. KNOWLEDGE_CONNECTOR = 8 # The query was handled by a # {::Google::Cloud::Dialogflow::CX::V3::Playbook `Playbook`}. PLAYBOOK = 9 end end |
#resolved_input ⇒ ::String
Returns Final text input which was matched during MatchIntent. This value can be different from original input sent in request because of spelling correction or other processing.
1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 1197 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/session.rb', line 1163 class Match include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of a Match. module MatchType # Not specified. Should never be used. MATCH_TYPE_UNSPECIFIED = 0 # The query was matched to an intent. INTENT = 1 # The query directly triggered an intent. DIRECT_INTENT = 2 # The query was used for parameter filling. PARAMETER_FILLING = 3 # No match was found for the query. NO_MATCH = 4 # Indicates an empty query. NO_INPUT = 5 # The query directly triggered an event. EVENT = 6 # The query was matched to a Knowledge Connector answer. KNOWLEDGE_CONNECTOR = 8 # The query was handled by a # {::Google::Cloud::Dialogflow::CX::V3::Playbook `Playbook`}. PLAYBOOK = 9 end end |