Class: Google::Cloud::Dialogflow::CX::V3::Playbook
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::CX::V3::Playbook
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb
Overview
Playbook is the basic building block to instruct the LLM how to execute a certain task.
A playbook consists of a goal to accomplish, an optional list of step by step instructions (the step instruction may refers to name of the custom or default plugin tools to use) to perform the task, a list of contextual input data to be passed in at the beginning of the invoked, and a list of output parameters to store the playbook result.
Defined Under Namespace
Modules: PlaybookType Classes: Instruction, Step
Instance Attribute Summary collapse
-
#code_block ⇒ ::Google::Cloud::Dialogflow::CX::V3::CodeBlock
Optional.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#display_name ⇒ ::String
Required.
-
#goal ⇒ ::String
Required.
-
#handlers ⇒ ::Array<::Google::Cloud::Dialogflow::CX::V3::Handler>
Optional.
-
#inline_actions ⇒ ::Array<::String>
readonly
Optional.
-
#input_parameter_definitions ⇒ ::Array<::Google::Cloud::Dialogflow::CX::V3::ParameterDefinition>
Optional.
-
#instruction ⇒ ::Google::Cloud::Dialogflow::CX::V3::Playbook::Instruction
Instruction to accomplish target goal.
-
#llm_model_settings ⇒ ::Google::Cloud::Dialogflow::CX::V3::LlmModelSettings
Optional.
-
#name ⇒ ::String
The unique identifier of the playbook.
-
#output_parameter_definitions ⇒ ::Array<::Google::Cloud::Dialogflow::CX::V3::ParameterDefinition>
Optional.
-
#playbook_type ⇒ ::Google::Cloud::Dialogflow::CX::V3::Playbook::PlaybookType
Optional.
-
#referenced_flows ⇒ ::Array<::String>
readonly
Output only.
-
#referenced_playbooks ⇒ ::Array<::String>
readonly
Output only.
-
#referenced_tools ⇒ ::Array<::String>
Optional.
-
#token_count ⇒ ::Integer
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#code_block ⇒ ::Google::Cloud::Dialogflow::CX::V3::CodeBlock
Returns Optional. The playbook's scoped code block, which may implement handlers and actions.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 183 class Playbook include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Message of single step execution. # @!attribute [rw] text # @return [::String] # Step instruction in text format. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Sub-processing needed to execute the current step. class Step include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Message of the Instruction of the playbook. # @!attribute [rw] guidelines # @return [::String] # General guidelines for the playbook. These are unstructured instructions # that are not directly part of the goal, e.g. "Always be polite". It's # valid for this text to be long and used instead of steps altogether. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Ordered list of step by step execution instructions to accomplish # target goal. class Instruction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of the playbook. module PlaybookType # Unspecified type. Default to TASK. PLAYBOOK_TYPE_UNSPECIFIED = 0 # Task playbook. TASK = 1 # Routine playbook. ROUTINE = 3 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The timestamp of initial playbook creation.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 183 class Playbook include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Message of single step execution. # @!attribute [rw] text # @return [::String] # Step instruction in text format. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Sub-processing needed to execute the current step. class Step include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Message of the Instruction of the playbook. # @!attribute [rw] guidelines # @return [::String] # General guidelines for the playbook. These are unstructured instructions # that are not directly part of the goal, e.g. "Always be polite". It's # valid for this text to be long and used instead of steps altogether. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Ordered list of step by step execution instructions to accomplish # target goal. class Instruction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of the playbook. module PlaybookType # Unspecified type. Default to TASK. PLAYBOOK_TYPE_UNSPECIFIED = 0 # Task playbook. TASK = 1 # Routine playbook. ROUTINE = 3 end end |
#display_name ⇒ ::String
Returns Required. The human-readable name of the playbook, unique within an agent.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 183 class Playbook include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Message of single step execution. # @!attribute [rw] text # @return [::String] # Step instruction in text format. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Sub-processing needed to execute the current step. class Step include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Message of the Instruction of the playbook. # @!attribute [rw] guidelines # @return [::String] # General guidelines for the playbook. These are unstructured instructions # that are not directly part of the goal, e.g. "Always be polite". It's # valid for this text to be long and used instead of steps altogether. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Ordered list of step by step execution instructions to accomplish # target goal. class Instruction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of the playbook. module PlaybookType # Unspecified type. Default to TASK. PLAYBOOK_TYPE_UNSPECIFIED = 0 # Task playbook. TASK = 1 # Routine playbook. ROUTINE = 3 end end |
#goal ⇒ ::String
Returns Required. High level description of the goal the playbook intend to accomplish. A goal should be concise since it's visible to other playbooks that may reference this playbook.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 183 class Playbook include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Message of single step execution. # @!attribute [rw] text # @return [::String] # Step instruction in text format. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Sub-processing needed to execute the current step. class Step include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Message of the Instruction of the playbook. # @!attribute [rw] guidelines # @return [::String] # General guidelines for the playbook. These are unstructured instructions # that are not directly part of the goal, e.g. "Always be polite". It's # valid for this text to be long and used instead of steps altogether. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Ordered list of step by step execution instructions to accomplish # target goal. class Instruction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of the playbook. module PlaybookType # Unspecified type. Default to TASK. PLAYBOOK_TYPE_UNSPECIFIED = 0 # Task playbook. TASK = 1 # Routine playbook. ROUTINE = 3 end end |
#handlers ⇒ ::Array<::Google::Cloud::Dialogflow::CX::V3::Handler>
Returns Optional. A list of registered handlers to execuate based on the specified triggers.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 183 class Playbook include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Message of single step execution. # @!attribute [rw] text # @return [::String] # Step instruction in text format. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Sub-processing needed to execute the current step. class Step include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Message of the Instruction of the playbook. # @!attribute [rw] guidelines # @return [::String] # General guidelines for the playbook. These are unstructured instructions # that are not directly part of the goal, e.g. "Always be polite". It's # valid for this text to be long and used instead of steps altogether. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Ordered list of step by step execution instructions to accomplish # target goal. class Instruction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of the playbook. module PlaybookType # Unspecified type. Default to TASK. PLAYBOOK_TYPE_UNSPECIFIED = 0 # Task playbook. TASK = 1 # Routine playbook. ROUTINE = 3 end end |
#inline_actions ⇒ ::Array<::String> (readonly)
Returns Optional. Output only. Names of inline actions scoped to this playbook. These actions are in addition to those belonging to referenced tools, child playbooks, and flows, e.g. actions that are defined in the playbook's code block.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 183 class Playbook include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Message of single step execution. # @!attribute [rw] text # @return [::String] # Step instruction in text format. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Sub-processing needed to execute the current step. class Step include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Message of the Instruction of the playbook. # @!attribute [rw] guidelines # @return [::String] # General guidelines for the playbook. These are unstructured instructions # that are not directly part of the goal, e.g. "Always be polite". It's # valid for this text to be long and used instead of steps altogether. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Ordered list of step by step execution instructions to accomplish # target goal. class Instruction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of the playbook. module PlaybookType # Unspecified type. Default to TASK. PLAYBOOK_TYPE_UNSPECIFIED = 0 # Task playbook. TASK = 1 # Routine playbook. ROUTINE = 3 end end |
#input_parameter_definitions ⇒ ::Array<::Google::Cloud::Dialogflow::CX::V3::ParameterDefinition>
Returns Optional. Defined structured input parameters for this playbook.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 183 class Playbook include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Message of single step execution. # @!attribute [rw] text # @return [::String] # Step instruction in text format. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Sub-processing needed to execute the current step. class Step include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Message of the Instruction of the playbook. # @!attribute [rw] guidelines # @return [::String] # General guidelines for the playbook. These are unstructured instructions # that are not directly part of the goal, e.g. "Always be polite". It's # valid for this text to be long and used instead of steps altogether. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Ordered list of step by step execution instructions to accomplish # target goal. class Instruction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of the playbook. module PlaybookType # Unspecified type. Default to TASK. PLAYBOOK_TYPE_UNSPECIFIED = 0 # Task playbook. TASK = 1 # Routine playbook. ROUTINE = 3 end end |
#instruction ⇒ ::Google::Cloud::Dialogflow::CX::V3::Playbook::Instruction
Returns Instruction to accomplish target goal.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 183 class Playbook include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Message of single step execution. # @!attribute [rw] text # @return [::String] # Step instruction in text format. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Sub-processing needed to execute the current step. class Step include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Message of the Instruction of the playbook. # @!attribute [rw] guidelines # @return [::String] # General guidelines for the playbook. These are unstructured instructions # that are not directly part of the goal, e.g. "Always be polite". It's # valid for this text to be long and used instead of steps altogether. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Ordered list of step by step execution instructions to accomplish # target goal. class Instruction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of the playbook. module PlaybookType # Unspecified type. Default to TASK. PLAYBOOK_TYPE_UNSPECIFIED = 0 # Task playbook. TASK = 1 # Routine playbook. ROUTINE = 3 end end |
#llm_model_settings ⇒ ::Google::Cloud::Dialogflow::CX::V3::LlmModelSettings
Returns Optional. Llm model settings for the playbook.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 183 class Playbook include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Message of single step execution. # @!attribute [rw] text # @return [::String] # Step instruction in text format. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Sub-processing needed to execute the current step. class Step include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Message of the Instruction of the playbook. # @!attribute [rw] guidelines # @return [::String] # General guidelines for the playbook. These are unstructured instructions # that are not directly part of the goal, e.g. "Always be polite". It's # valid for this text to be long and used instead of steps altogether. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Ordered list of step by step execution instructions to accomplish # target goal. class Instruction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of the playbook. module PlaybookType # Unspecified type. Default to TASK. PLAYBOOK_TYPE_UNSPECIFIED = 0 # Task playbook. TASK = 1 # Routine playbook. ROUTINE = 3 end end |
#name ⇒ ::String
Returns The unique identifier of the playbook.
Format:
projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 183 class Playbook include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Message of single step execution. # @!attribute [rw] text # @return [::String] # Step instruction in text format. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Sub-processing needed to execute the current step. class Step include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Message of the Instruction of the playbook. # @!attribute [rw] guidelines # @return [::String] # General guidelines for the playbook. These are unstructured instructions # that are not directly part of the goal, e.g. "Always be polite". It's # valid for this text to be long and used instead of steps altogether. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Ordered list of step by step execution instructions to accomplish # target goal. class Instruction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of the playbook. module PlaybookType # Unspecified type. Default to TASK. PLAYBOOK_TYPE_UNSPECIFIED = 0 # Task playbook. TASK = 1 # Routine playbook. ROUTINE = 3 end end |
#output_parameter_definitions ⇒ ::Array<::Google::Cloud::Dialogflow::CX::V3::ParameterDefinition>
Returns Optional. Defined structured output parameters for this playbook.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 183 class Playbook include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Message of single step execution. # @!attribute [rw] text # @return [::String] # Step instruction in text format. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Sub-processing needed to execute the current step. class Step include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Message of the Instruction of the playbook. # @!attribute [rw] guidelines # @return [::String] # General guidelines for the playbook. These are unstructured instructions # that are not directly part of the goal, e.g. "Always be polite". It's # valid for this text to be long and used instead of steps altogether. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Ordered list of step by step execution instructions to accomplish # target goal. class Instruction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of the playbook. module PlaybookType # Unspecified type. Default to TASK. PLAYBOOK_TYPE_UNSPECIFIED = 0 # Task playbook. TASK = 1 # Routine playbook. ROUTINE = 3 end end |
#playbook_type ⇒ ::Google::Cloud::Dialogflow::CX::V3::Playbook::PlaybookType
Returns Optional. Type of the playbook.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 183 class Playbook include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Message of single step execution. # @!attribute [rw] text # @return [::String] # Step instruction in text format. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Sub-processing needed to execute the current step. class Step include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Message of the Instruction of the playbook. # @!attribute [rw] guidelines # @return [::String] # General guidelines for the playbook. These are unstructured instructions # that are not directly part of the goal, e.g. "Always be polite". It's # valid for this text to be long and used instead of steps altogether. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Ordered list of step by step execution instructions to accomplish # target goal. class Instruction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of the playbook. module PlaybookType # Unspecified type. Default to TASK. PLAYBOOK_TYPE_UNSPECIFIED = 0 # Task playbook. TASK = 1 # Routine playbook. ROUTINE = 3 end end |
#referenced_flows ⇒ ::Array<::String> (readonly)
Returns Output only. The resource name of flows referenced by the current playbook in the instructions.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 183 class Playbook include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Message of single step execution. # @!attribute [rw] text # @return [::String] # Step instruction in text format. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Sub-processing needed to execute the current step. class Step include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Message of the Instruction of the playbook. # @!attribute [rw] guidelines # @return [::String] # General guidelines for the playbook. These are unstructured instructions # that are not directly part of the goal, e.g. "Always be polite". It's # valid for this text to be long and used instead of steps altogether. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Ordered list of step by step execution instructions to accomplish # target goal. class Instruction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of the playbook. module PlaybookType # Unspecified type. Default to TASK. PLAYBOOK_TYPE_UNSPECIFIED = 0 # Task playbook. TASK = 1 # Routine playbook. ROUTINE = 3 end end |
#referenced_playbooks ⇒ ::Array<::String> (readonly)
Returns Output only. The resource name of other playbooks referenced by the current playbook in the instructions.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 183 class Playbook include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Message of single step execution. # @!attribute [rw] text # @return [::String] # Step instruction in text format. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Sub-processing needed to execute the current step. class Step include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Message of the Instruction of the playbook. # @!attribute [rw] guidelines # @return [::String] # General guidelines for the playbook. These are unstructured instructions # that are not directly part of the goal, e.g. "Always be polite". It's # valid for this text to be long and used instead of steps altogether. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Ordered list of step by step execution instructions to accomplish # target goal. class Instruction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of the playbook. module PlaybookType # Unspecified type. Default to TASK. PLAYBOOK_TYPE_UNSPECIFIED = 0 # Task playbook. TASK = 1 # Routine playbook. ROUTINE = 3 end end |
#referenced_tools ⇒ ::Array<::String>
Returns Optional. The resource name of tools referenced by the current playbook in the instructions. If not provided explicitly, they are will be implied using the tool being referenced in goal and steps.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 183 class Playbook include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Message of single step execution. # @!attribute [rw] text # @return [::String] # Step instruction in text format. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Sub-processing needed to execute the current step. class Step include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Message of the Instruction of the playbook. # @!attribute [rw] guidelines # @return [::String] # General guidelines for the playbook. These are unstructured instructions # that are not directly part of the goal, e.g. "Always be polite". It's # valid for this text to be long and used instead of steps altogether. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Ordered list of step by step execution instructions to accomplish # target goal. class Instruction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of the playbook. module PlaybookType # Unspecified type. Default to TASK. PLAYBOOK_TYPE_UNSPECIFIED = 0 # Task playbook. TASK = 1 # Routine playbook. ROUTINE = 3 end end |
#token_count ⇒ ::Integer (readonly)
Returns Output only. Estimated number of tokes current playbook takes when sent to the LLM.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 183 class Playbook include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Message of single step execution. # @!attribute [rw] text # @return [::String] # Step instruction in text format. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Sub-processing needed to execute the current step. class Step include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Message of the Instruction of the playbook. # @!attribute [rw] guidelines # @return [::String] # General guidelines for the playbook. These are unstructured instructions # that are not directly part of the goal, e.g. "Always be polite". It's # valid for this text to be long and used instead of steps altogether. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Ordered list of step by step execution instructions to accomplish # target goal. class Instruction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of the playbook. module PlaybookType # Unspecified type. Default to TASK. PLAYBOOK_TYPE_UNSPECIFIED = 0 # Task playbook. TASK = 1 # Routine playbook. ROUTINE = 3 end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Last time the playbook version was updated.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 183 class Playbook include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Message of single step execution. # @!attribute [rw] text # @return [::String] # Step instruction in text format. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Sub-processing needed to execute the current step. class Step include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Message of the Instruction of the playbook. # @!attribute [rw] guidelines # @return [::String] # General guidelines for the playbook. These are unstructured instructions # that are not directly part of the goal, e.g. "Always be polite". It's # valid for this text to be long and used instead of steps altogether. # @!attribute [rw] steps # @return [::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>] # Ordered list of step by step execution instructions to accomplish # target goal. class Instruction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of the playbook. module PlaybookType # Unspecified type. Default to TASK. PLAYBOOK_TYPE_UNSPECIFIED = 0 # Task playbook. TASK = 1 # Routine playbook. ROUTINE = 3 end end |