Class: Google::Cloud::Dialogflow::CX::V3::Playbook::Instruction
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::CX::V3::Playbook::Instruction
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb
Overview
Message of the Instruction of the playbook.
Instance Attribute Summary collapse
-
#guidelines ⇒ ::String
General guidelines for the playbook.
-
#steps ⇒ ::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>
Ordered list of step by step execution instructions to accomplish target goal.
Instance Attribute Details
#guidelines ⇒ ::String
Returns General guidelines for the playbook. These are unstructured instructions that are not directly part of the goal, e.g. "Always be polite". It's valid for this text to be long and used instead of steps altogether.
209 210 211 212 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 209 class Instruction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#steps ⇒ ::Array<::Google::Cloud::Dialogflow::CX::V3::Playbook::Step>
Returns Ordered list of step by step execution instructions to accomplish target goal.
209 210 211 212 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/playbook.rb', line 209 class Instruction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |