Class: Google::Cloud::Dialogflow::CX::V3::PlaybookTransition
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::CX::V3::PlaybookTransition
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/cx/v3/trace.rb
Overview
Stores metadata of the transition to another target playbook. Playbook transition actions exit the caller playbook and enter the target playbook.
Instance Attribute Summary collapse
-
#display_name ⇒ ::String
readonly
Output only.
-
#playbook ⇒ ::String
Required.
Instance Attribute Details
#display_name ⇒ ::String (readonly)
Returns Output only. The display name of the playbook.
257 258 259 260 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/trace.rb', line 257 class PlaybookTransition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#playbook ⇒ ::String
Returns Required. The unique identifier of the playbook.
Format:
projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>.
257 258 259 260 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/trace.rb', line 257 class PlaybookTransition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |