Class: Google::Cloud::Dialogflow::CX::V3::RestoreAgentRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::CX::V3::RestoreAgentRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/cx/v3/agent.rb
Overview
The request message for Agents.RestoreAgent.
Defined Under Namespace
Modules: RestoreOption Classes: GitSource
Instance Attribute Summary collapse
-
#agent_content ⇒ ::String
Uncompressed raw byte content for agent.
-
#agent_uri ⇒ ::String
The Google Cloud Storage URI to restore agent from.
-
#git_source ⇒ ::Google::Cloud::Dialogflow::CX::V3::RestoreAgentRequest::GitSource
Setting for restoring from a git branch.
-
#name ⇒ ::String
Required.
-
#restore_option ⇒ ::Google::Cloud::Dialogflow::CX::V3::RestoreAgentRequest::RestoreOption
Agent restore mode.
Instance Attribute Details
#agent_content ⇒ ::String
Returns Uncompressed raw byte content for agent.
Note: The following fields are mutually exclusive: agent_content, agent_uri, git_source. If a field in that set is populated, all other fields in the set will automatically be cleared.
470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/agent.rb', line 470 class RestoreAgentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for restoring from a git branch # @!attribute [rw] tracking_branch # @return [::String] # tracking branch for the git pull class GitSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Restore option. module RestoreOption # Unspecified. Treated as KEEP. RESTORE_OPTION_UNSPECIFIED = 0 # Always respect the settings from the exported agent file. It may cause # a restoration failure if some settings (e.g. model type) are not # supported in the target agent. KEEP = 1 # Fallback to default settings if some settings are not supported in the # target agent. FALLBACK = 2 end end |
#agent_uri ⇒ ::String
Returns The Google Cloud Storage URI
to restore agent from. The format of this URI must be
gs://<bucket-name>/<object-name>.
Dialogflow performs a read operation for the Cloud Storage object on the caller's behalf, so your request authentication must have read permissions for the object. For more information, see Dialogflow access control.
Note: The following fields are mutually exclusive: agent_uri, agent_content, git_source. If a field in that set is populated, all other fields in the set will automatically be cleared.
470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/agent.rb', line 470 class RestoreAgentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for restoring from a git branch # @!attribute [rw] tracking_branch # @return [::String] # tracking branch for the git pull class GitSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Restore option. module RestoreOption # Unspecified. Treated as KEEP. RESTORE_OPTION_UNSPECIFIED = 0 # Always respect the settings from the exported agent file. It may cause # a restoration failure if some settings (e.g. model type) are not # supported in the target agent. KEEP = 1 # Fallback to default settings if some settings are not supported in the # target agent. FALLBACK = 2 end end |
#git_source ⇒ ::Google::Cloud::Dialogflow::CX::V3::RestoreAgentRequest::GitSource
Returns Setting for restoring from a git branch
Note: The following fields are mutually exclusive: git_source, agent_uri, agent_content. If a field in that set is populated, all other fields in the set will automatically be cleared.
470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/agent.rb', line 470 class RestoreAgentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for restoring from a git branch # @!attribute [rw] tracking_branch # @return [::String] # tracking branch for the git pull class GitSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Restore option. module RestoreOption # Unspecified. Treated as KEEP. RESTORE_OPTION_UNSPECIFIED = 0 # Always respect the settings from the exported agent file. It may cause # a restoration failure if some settings (e.g. model type) are not # supported in the target agent. KEEP = 1 # Fallback to default settings if some settings are not supported in the # target agent. FALLBACK = 2 end end |
#name ⇒ ::String
Returns Required. The name of the agent to restore into.
Format: projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>.
470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/agent.rb', line 470 class RestoreAgentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for restoring from a git branch # @!attribute [rw] tracking_branch # @return [::String] # tracking branch for the git pull class GitSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Restore option. module RestoreOption # Unspecified. Treated as KEEP. RESTORE_OPTION_UNSPECIFIED = 0 # Always respect the settings from the exported agent file. It may cause # a restoration failure if some settings (e.g. model type) are not # supported in the target agent. KEEP = 1 # Fallback to default settings if some settings are not supported in the # target agent. FALLBACK = 2 end end |
#restore_option ⇒ ::Google::Cloud::Dialogflow::CX::V3::RestoreAgentRequest::RestoreOption
Returns Agent restore mode. If not specified, KEEP is assumed.
470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/agent.rb', line 470 class RestoreAgentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for restoring from a git branch # @!attribute [rw] tracking_branch # @return [::String] # tracking branch for the git pull class GitSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Restore option. module RestoreOption # Unspecified. Treated as KEEP. RESTORE_OPTION_UNSPECIFIED = 0 # Always respect the settings from the exported agent file. It may cause # a restoration failure if some settings (e.g. model type) are not # supported in the target agent. KEEP = 1 # Fallback to default settings if some settings are not supported in the # target agent. FALLBACK = 2 end end |