Class: Google::Cloud::Dialogflow::CX::V3::RestoreAgentRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/cx/v3/agent.rb

Overview

The request message for Agents.RestoreAgent.

Defined Under Namespace

Modules: RestoreOption

Instance Attribute Summary collapse

Instance Attribute Details

#agent_content::String

Returns Uncompressed raw byte content for agent.

Returns:

  • (::String)

    Uncompressed raw byte content for agent.



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'proto_docs/google/cloud/dialogflow/cx/v3/agent.rb', line 296

class RestoreAgentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Restore option.
  module RestoreOption
    # Unspecified. Treated as KEEP.
    RESTORE_OPTION_UNSPECIFIED = 0

    # Always respect the settings from the exported agent file. It may cause
    # a restoration failure if some settings (e.g. model type) are not
    # supported in the target agent.
    KEEP = 1

    # Fallback to default settings if some settings are not supported in the
    # target agent.
    FALLBACK = 2
  end
end

#agent_uri::String

Returns The Google Cloud Storage URI to restore agent from. The format of this URI must be gs://<bucket-name>/<object-name>.

Dialogflow performs a read operation for the Cloud Storage object on the caller's behalf, so your request authentication must have read permissions for the object. For more information, see Dialogflow access control.

Returns:

  • (::String)

    The Google Cloud Storage URI to restore agent from. The format of this URI must be gs://<bucket-name>/<object-name>.

    Dialogflow performs a read operation for the Cloud Storage object on the caller's behalf, so your request authentication must have read permissions for the object. For more information, see Dialogflow access control.



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'proto_docs/google/cloud/dialogflow/cx/v3/agent.rb', line 296

class RestoreAgentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Restore option.
  module RestoreOption
    # Unspecified. Treated as KEEP.
    RESTORE_OPTION_UNSPECIFIED = 0

    # Always respect the settings from the exported agent file. It may cause
    # a restoration failure if some settings (e.g. model type) are not
    # supported in the target agent.
    KEEP = 1

    # Fallback to default settings if some settings are not supported in the
    # target agent.
    FALLBACK = 2
  end
end

#name::String

Returns Required. The name of the agent to restore into. Format: projects/<Project ID>/locations/<Location ID>/agents/<Agent ID>.

Returns:

  • (::String)

    Required. The name of the agent to restore into. Format: projects/<Project ID>/locations/<Location ID>/agents/<Agent ID>.



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'proto_docs/google/cloud/dialogflow/cx/v3/agent.rb', line 296

class RestoreAgentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Restore option.
  module RestoreOption
    # Unspecified. Treated as KEEP.
    RESTORE_OPTION_UNSPECIFIED = 0

    # Always respect the settings from the exported agent file. It may cause
    # a restoration failure if some settings (e.g. model type) are not
    # supported in the target agent.
    KEEP = 1

    # Fallback to default settings if some settings are not supported in the
    # target agent.
    FALLBACK = 2
  end
end

#restore_option::Google::Cloud::Dialogflow::CX::V3::RestoreAgentRequest::RestoreOption

Returns Agent restore mode. If not specified, KEEP is assumed.

Returns:



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'proto_docs/google/cloud/dialogflow/cx/v3/agent.rb', line 296

class RestoreAgentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Restore option.
  module RestoreOption
    # Unspecified. Treated as KEEP.
    RESTORE_OPTION_UNSPECIFIED = 0

    # Always respect the settings from the exported agent file. It may cause
    # a restoration failure if some settings (e.g. model type) are not
    # supported in the target agent.
    KEEP = 1

    # Fallback to default settings if some settings are not supported in the
    # target agent.
    FALLBACK = 2
  end
end