Class: Google::Cloud::Dialogflow::CX::V3::RestoreAgentRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::CX::V3::RestoreAgentRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/cx/v3/agent.rb
Overview
The request message for Agents.RestoreAgent.
Defined Under Namespace
Modules: RestoreOption
Instance Attribute Summary collapse
-
#agent_content ⇒ ::String
Uncompressed raw byte content for agent.
-
#agent_uri ⇒ ::String
The Google Cloud Storage URI to restore agent from.
-
#name ⇒ ::String
Required.
-
#restore_option ⇒ ::Google::Cloud::Dialogflow::CX::V3::RestoreAgentRequest::RestoreOption
Agent restore mode.
Instance Attribute Details
#agent_content ⇒ ::String
Returns Uncompressed raw byte content for agent.
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/agent.rb', line 265 class RestoreAgentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Restore option. module RestoreOption # Unspecified. Treated as KEEP. RESTORE_OPTION_UNSPECIFIED = 0 # Always respect the settings from the exported agent file. It may cause # a restoration failure if some settings (e.g. model type) are not # supported in the target agent. KEEP = 1 # Fallback to default settings if some settings are not supported in the # target agent. FALLBACK = 2 end end |
#agent_uri ⇒ ::String
Returns The Google Cloud Storage URI
to restore agent from. The format of this URI must be
gs://<bucket-name>/<object-name>.
Dialogflow performs a read operation for the Cloud Storage object on the caller's behalf, so your request authentication must have read permissions for the object. For more information, see Dialogflow access control.
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/agent.rb', line 265 class RestoreAgentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Restore option. module RestoreOption # Unspecified. Treated as KEEP. RESTORE_OPTION_UNSPECIFIED = 0 # Always respect the settings from the exported agent file. It may cause # a restoration failure if some settings (e.g. model type) are not # supported in the target agent. KEEP = 1 # Fallback to default settings if some settings are not supported in the # target agent. FALLBACK = 2 end end |
#name ⇒ ::String
Returns Required. The name of the agent to restore into.
Format: projects/<Project ID>/locations/<Location ID>/agents/<Agent ID>.
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/agent.rb', line 265 class RestoreAgentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Restore option. module RestoreOption # Unspecified. Treated as KEEP. RESTORE_OPTION_UNSPECIFIED = 0 # Always respect the settings from the exported agent file. It may cause # a restoration failure if some settings (e.g. model type) are not # supported in the target agent. KEEP = 1 # Fallback to default settings if some settings are not supported in the # target agent. FALLBACK = 2 end end |
#restore_option ⇒ ::Google::Cloud::Dialogflow::CX::V3::RestoreAgentRequest::RestoreOption
Returns Agent restore mode. If not specified, KEEP is assumed.
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/agent.rb', line 265 class RestoreAgentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Restore option. module RestoreOption # Unspecified. Treated as KEEP. RESTORE_OPTION_UNSPECIFIED = 0 # Always respect the settings from the exported agent file. It may cause # a restoration failure if some settings (e.g. model type) are not # supported in the target agent. KEEP = 1 # Fallback to default settings if some settings are not supported in the # target agent. FALLBACK = 2 end end |