Class: Google::Cloud::Dialogflow::CX::V3::SecuritySettings::AudioExportSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/cx/v3/security_settings.rb

Overview

Settings for exporting audio.

Defined Under Namespace

Modules: AudioFormat

Instance Attribute Summary collapse

Instance Attribute Details

#audio_export_pattern::String

Returns Filename pattern for exported audio.

Returns:

  • (::String)

    Filename pattern for exported audio.



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'proto_docs/google/cloud/dialogflow/cx/v3/security_settings.rb', line 222

class AudioExportSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # File format for exported audio file. Currently only in telephony
  # recordings.
  module AudioFormat
    # Unspecified. Do not use.
    AUDIO_FORMAT_UNSPECIFIED = 0

    # G.711 mu-law PCM with 8kHz sample rate.
    MULAW = 1

    # MP3 file format.
    MP3 = 2

    # OGG Vorbis.
    OGG = 3
  end
end

#audio_format::Google::Cloud::Dialogflow::CX::V3::SecuritySettings::AudioExportSettings::AudioFormat

Returns File format for exported audio file. Currently only in telephony recordings.

Returns:



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'proto_docs/google/cloud/dialogflow/cx/v3/security_settings.rb', line 222

class AudioExportSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # File format for exported audio file. Currently only in telephony
  # recordings.
  module AudioFormat
    # Unspecified. Do not use.
    AUDIO_FORMAT_UNSPECIFIED = 0

    # G.711 mu-law PCM with 8kHz sample rate.
    MULAW = 1

    # MP3 file format.
    MP3 = 2

    # OGG Vorbis.
    OGG = 3
  end
end

#enable_audio_redaction::Boolean

Returns Enable audio redaction if it is true.

Returns:

  • (::Boolean)

    Enable audio redaction if it is true.



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'proto_docs/google/cloud/dialogflow/cx/v3/security_settings.rb', line 222

class AudioExportSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # File format for exported audio file. Currently only in telephony
  # recordings.
  module AudioFormat
    # Unspecified. Do not use.
    AUDIO_FORMAT_UNSPECIFIED = 0

    # G.711 mu-law PCM with 8kHz sample rate.
    MULAW = 1

    # MP3 file format.
    MP3 = 2

    # OGG Vorbis.
    OGG = 3
  end
end

#gcs_bucket::String

Returns Cloud Storage bucket to export audio record to. You need to grant service-<Conversation Project Number>@gcp-sa-dialogflow.iam.gserviceaccount.com the Storage Object Admin role in this bucket.

Returns:

  • (::String)

    Cloud Storage bucket to export audio record to. You need to grant service-<Conversation Project Number>@gcp-sa-dialogflow.iam.gserviceaccount.com the Storage Object Admin role in this bucket.



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'proto_docs/google/cloud/dialogflow/cx/v3/security_settings.rb', line 222

class AudioExportSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # File format for exported audio file. Currently only in telephony
  # recordings.
  module AudioFormat
    # Unspecified. Do not use.
    AUDIO_FORMAT_UNSPECIFIED = 0

    # G.711 mu-law PCM with 8kHz sample rate.
    MULAW = 1

    # MP3 file format.
    MP3 = 2

    # OGG Vorbis.
    OGG = 3
  end
end