Class: Google::Cloud::Dialogflow::CX::V3::SessionInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::CX::V3::SessionInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/cx/v3/webhook.rb
Overview
Represents session information communicated to and from the webhook.
Defined Under Namespace
Classes: ParametersEntry
Instance Attribute Summary collapse
-
#parameters ⇒ ::Google::Protobuf::Map{::String => ::Google::Protobuf::Value}
Optional for WebhookRequest.
-
#session ⇒ ::String
Always present for WebhookRequest.
Instance Attribute Details
#parameters ⇒ ::Google::Protobuf::Map{::String => ::Google::Protobuf::Value}
Returns Optional for WebhookRequest. Optional for WebhookResponse. All parameters collected from forms and intents during the session. Parameters can be created, updated, or removed by the webhook. To remove a parameter from the session, the webhook should explicitly set the parameter value to null in WebhookResponse. The map is keyed by parameters' display names.
748 749 750 751 752 753 754 755 756 757 758 759 760 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/webhook.rb', line 748 class SessionInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Protobuf::Value] class ParametersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#session ⇒ ::String
Returns Always present for
WebhookRequest. Ignored for
WebhookResponse. The
unique identifier of the
session. This
field can be used by the webhook to identify a session.
Format:
projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/sessions/<SessionID>
or
projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/environments/<EnvironmentID>/sessions/<SessionID>
if environment is specified.
748 749 750 751 752 753 754 755 756 757 758 759 760 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/webhook.rb', line 748 class SessionInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Protobuf::Value] class ParametersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |