Class: Google::Cloud::Dialogflow::CX::V3::Tool::DataStoreTool
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::CX::V3::Tool::DataStoreTool
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/cx/v3/tool.rb
Overview
A DataStoreTool is a way to provide specifications needed to search a list of data stores.
Defined Under Namespace
Classes: FallbackPrompt
Instance Attribute Summary collapse
-
#data_store_connections ⇒ ::Array<::Google::Cloud::Dialogflow::CX::V3::DataStoreConnection>
Required.
-
#fallback_prompt ⇒ ::Google::Cloud::Dialogflow::CX::V3::Tool::DataStoreTool::FallbackPrompt
Required.
Instance Attribute Details
#data_store_connections ⇒ ::Array<::Google::Cloud::Dialogflow::CX::V3::DataStoreConnection>
Returns Required. List of data stores to search.
183 184 185 186 187 188 189 190 191 192 193 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/tool.rb', line 183 class DataStoreTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A FallbackPrompt is a way to provide specifications for the Data Store # fallback prompt when generating responses. class FallbackPrompt include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#fallback_prompt ⇒ ::Google::Cloud::Dialogflow::CX::V3::Tool::DataStoreTool::FallbackPrompt
Returns Required. Fallback prompt configurations to use.
183 184 185 186 187 188 189 190 191 192 193 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/tool.rb', line 183 class DataStoreTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A FallbackPrompt is a way to provide specifications for the Data Store # fallback prompt when generating responses. class FallbackPrompt include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |