Class: Google::Cloud::Dialogflow::CX::V3::ToolCallResult
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::CX::V3::ToolCallResult
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/cx/v3/tool_call.rb
Overview
The result of calling a tool's action that has been executed by the client.
Defined Under Namespace
Classes: Error
Instance Attribute Summary collapse
-
#action ⇒ ::String
Required.
-
#error ⇒ ::Google::Cloud::Dialogflow::CX::V3::ToolCallResult::Error
The tool call's error.
-
#output_parameters ⇒ ::Google::Protobuf::Struct
The tool call's output parameters.
-
#tool ⇒ ::String
Required.
Instance Attribute Details
#action ⇒ ::String
Returns Required. The name of the tool's action associated with this call.
61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/tool_call.rb', line 61 class ToolCallResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An error produced by the tool call. # @!attribute [rw] message # @return [::String] # Optional. The error message of the function. class Error include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#error ⇒ ::Google::Cloud::Dialogflow::CX::V3::ToolCallResult::Error
Returns The tool call's error.
Note: The following fields are mutually exclusive: error, output_parameters. If a field in that set is populated, all other fields in the set will automatically be cleared.
61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/tool_call.rb', line 61 class ToolCallResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An error produced by the tool call. # @!attribute [rw] message # @return [::String] # Optional. The error message of the function. class Error include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#output_parameters ⇒ ::Google::Protobuf::Struct
Returns The tool call's output parameters.
Note: The following fields are mutually exclusive: output_parameters, error. If a field in that set is populated, all other fields in the set will automatically be cleared.
61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/tool_call.rb', line 61 class ToolCallResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An error produced by the tool call. # @!attribute [rw] message # @return [::String] # Optional. The error message of the function. class Error include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#tool ⇒ ::String
Returns Required. The tool associated with
this call. Format:
projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/tools/<ToolID>.
61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/tool_call.rb', line 61 class ToolCallResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An error produced by the tool call. # @!attribute [rw] message # @return [::String] # Optional. The error message of the function. class Error include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |