Class: Google::Cloud::Dialogflow::CX::V3::ToolVersion
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::CX::V3::ToolVersion
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/cx/v3/tool.rb
Overview
Tool version is a snapshot of the tool at certain timestamp.
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#display_name ⇒ ::String
Required.
-
#name ⇒ ::String
Identifier.
-
#tool ⇒ ::Google::Cloud::Dialogflow::CX::V3::Tool
Required.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Last time the tool version was created or modified.
580 581 582 583 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/tool.rb', line 580 class ToolVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#display_name ⇒ ::String
Returns Required. The display name of the tool version.
580 581 582 583 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/tool.rb', line 580 class ToolVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Identifier. The unique identifier of the tool version.
Format:
projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/tools/<ToolID>/versions/<VersionID>.
580 581 582 583 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/tool.rb', line 580 class ToolVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tool ⇒ ::Google::Cloud::Dialogflow::CX::V3::Tool
Returns Required. Snapshot of the tool to be associated with this version.
580 581 582 583 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/tool.rb', line 580 class ToolVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Last time the tool version was created or modified.
580 581 582 583 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/tool.rb', line 580 class ToolVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |