Class: Google::Cloud::Dialogflow::CX::V3::Tools::Rest::Client
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::CX::V3::Tools::Rest::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb
Overview
REST client for the Tools service.
Service for managing Tools.
Defined Under Namespace
Classes: Configuration
Instance Attribute Summary collapse
-
#location_client ⇒ Google::Cloud::Location::Locations::Rest::Client
readonly
Get the associated client for mix-in of the Locations.
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the Tools Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the Tools Client instance.
-
#create_tool(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Dialogflow::CX::V3::Tool
Creates a Tool in the specified agent.
-
#create_tool_version(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Dialogflow::CX::V3::ToolVersion
Creates a version for the specified Tool.
-
#delete_tool(request, options = nil) {|result, operation| ... } ⇒ ::Google::Protobuf::Empty
Deletes a specified Tool.
-
#delete_tool_version(request, options = nil) {|result, operation| ... } ⇒ ::Google::Protobuf::Empty
Deletes the specified version of the Tool.
-
#get_tool(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Dialogflow::CX::V3::Tool
Retrieves the specified Tool.
-
#get_tool_version(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Dialogflow::CX::V3::ToolVersion
Retrieves the specified version of the Tool.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new Tools REST client object.
-
#list_tool_versions(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dialogflow::CX::V3::ToolVersion>
List versions of the specified Tool.
-
#list_tools(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dialogflow::CX::V3::Tool>
Returns a list of Tools in the specified agent.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#restore_tool_version(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Dialogflow::CX::V3::RestoreToolVersionResponse
Retrieves the specified version of the Tool and stores it as the current tool draft, returning the tool with resources updated.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_tool(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Dialogflow::CX::V3::Tool
Update the specified Tool.
Methods included from Paths
#agent_path, #secret_version_path, #service_path, #tool_path, #tool_version_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new Tools REST client object.
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb', line 133 def initialize # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @tools_stub = ::Google::Cloud::Dialogflow::CX::V3::Tools::Rest::ServiceStub.new( endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, credentials: credentials, logger: @config.logger ) @tools_stub.logger(stub: true)&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end @location_client = Google::Cloud::Location::Locations::Rest::Client.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @tools_stub.endpoint config.universe_domain = @tools_stub.universe_domain config.bindings_override = @config.bindings_override config.logger = @tools_stub.logger if config.respond_to? :logger= end end |
Instance Attribute Details
#location_client ⇒ Google::Cloud::Location::Locations::Rest::Client (readonly)
Get the associated client for mix-in of the Locations.
189 190 191 |
# File 'lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb', line 189 def location_client @location_client end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the Tools Client class.
See Configuration for a description of the configuration fields.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb', line 66 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "Dialogflow", "CX", "V3"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.timeout = 60.0 default_config.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the Tools Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
103 104 105 106 |
# File 'lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb', line 103 def configure yield @config if block_given? @config end |
#create_tool(request, options = nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::Tool #create_tool(parent: nil, tool: nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::Tool
Creates a Tool in the specified agent.
249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb', line 249 def create_tool request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dialogflow::CX::V3::CreateToolRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_tool..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dialogflow::CX::V3::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.create_tool.timeout, metadata: , retry_policy: @config.rpcs.create_tool.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @tools_stub.create_tool request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#create_tool_version(request, options = nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::ToolVersion #create_tool_version(parent: nil, tool_version: nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::ToolVersion
Creates a version for the specified Tool.
763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 |
# File 'lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb', line 763 def create_tool_version request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dialogflow::CX::V3::CreateToolVersionRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_tool_version..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dialogflow::CX::V3::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.create_tool_version.timeout, metadata: , retry_policy: @config.rpcs.create_tool_version.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @tools_stub.create_tool_version request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_tool(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_tool(name: nil, force: nil) ⇒ ::Google::Protobuf::Empty
Deletes a specified Tool.
589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 |
# File 'lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb', line 589 def delete_tool request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dialogflow::CX::V3::DeleteToolRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_tool..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dialogflow::CX::V3::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.delete_tool.timeout, metadata: , retry_policy: @config.rpcs.delete_tool.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @tools_stub.delete_tool request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_tool_version(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_tool_version(name: nil, force: nil) ⇒ ::Google::Protobuf::Empty
Deletes the specified version of the Tool.
933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 |
# File 'lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb', line 933 def delete_tool_version request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dialogflow::CX::V3::DeleteToolVersionRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_tool_version..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dialogflow::CX::V3::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.delete_tool_version.timeout, metadata: , retry_policy: @config.rpcs.delete_tool_version.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @tools_stub.delete_tool_version request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#get_tool(request, options = nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::Tool #get_tool(name: nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::Tool
Retrieves the specified Tool.
420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 |
# File 'lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb', line 420 def get_tool request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dialogflow::CX::V3::GetToolRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_tool..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dialogflow::CX::V3::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_tool.timeout, metadata: , retry_policy: @config.rpcs.get_tool.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @tools_stub.get_tool request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#get_tool_version(request, options = nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::ToolVersion #get_tool_version(name: nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::ToolVersion
Retrieves the specified version of the Tool.
844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 |
# File 'lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb', line 844 def get_tool_version request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dialogflow::CX::V3::GetToolVersionRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_tool_version..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dialogflow::CX::V3::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_tool_version.timeout, metadata: , retry_policy: @config.rpcs.get_tool_version.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @tools_stub.get_tool_version request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#list_tool_versions(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dialogflow::CX::V3::ToolVersion> #list_tool_versions(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dialogflow::CX::V3::ToolVersion>
List versions of the specified Tool.
678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 |
# File 'lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb', line 678 def list_tool_versions request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dialogflow::CX::V3::ListToolVersionsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_tool_versions..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dialogflow::CX::V3::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list_tool_versions.timeout, metadata: , retry_policy: @config.rpcs.list_tool_versions.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @tools_stub.list_tool_versions request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @tools_stub, :list_tool_versions, "tool_versions", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#list_tools(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dialogflow::CX::V3::Tool> #list_tools(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dialogflow::CX::V3::Tool>
Returns a list of Tools in the specified agent.
338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb', line 338 def list_tools request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dialogflow::CX::V3::ListToolsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_tools..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dialogflow::CX::V3::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list_tools.timeout, metadata: , retry_policy: @config.rpcs.list_tools.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @tools_stub.list_tools request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @tools_stub, :list_tools, "tools", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
196 197 198 |
# File 'lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb', line 196 def logger @tools_stub.logger end |
#restore_tool_version(request, options = nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::RestoreToolVersionResponse #restore_tool_version(name: nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::RestoreToolVersionResponse
Retrieves the specified version of the Tool and stores it as the current tool draft, returning the tool with resources updated.
1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 |
# File 'lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb', line 1014 def restore_tool_version request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dialogflow::CX::V3::RestoreToolVersionRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.restore_tool_version..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dialogflow::CX::V3::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.restore_tool_version.timeout, metadata: , retry_policy: @config.rpcs.restore_tool_version.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @tools_stub.restore_tool_version request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#universe_domain ⇒ String
The effective universe domain
113 114 115 |
# File 'lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb', line 113 def universe_domain @tools_stub.universe_domain end |
#update_tool(request, options = nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::Tool #update_tool(tool: nil, update_mask: nil) ⇒ ::Google::Cloud::Dialogflow::CX::V3::Tool
Update the specified Tool.
501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 |
# File 'lib/google/cloud/dialogflow/cx/v3/tools/rest/client.rb', line 501 def update_tool request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dialogflow::CX::V3::UpdateToolRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_tool..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dialogflow::CX::V3::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.update_tool.timeout, metadata: , retry_policy: @config.rpcs.update_tool.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @tools_stub.update_tool request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |