Class: Google::Cloud::Dialogflow::CX::V3::TraceBlock
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::CX::V3::TraceBlock
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/cx/v3/trace.rb
Overview
The trace block tracks a sequence of actions taken by the agent in a flow or a playbook.
Instance Attribute Summary collapse
-
#actions ⇒ ::Array<::Google::Cloud::Dialogflow::CX::V3::Action>
The actions performed by the agent and the user during this session.
-
#complete_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#end_state ⇒ ::Google::Cloud::Dialogflow::CX::V3::OutputState
readonly
Optional.
-
#flow_trace_metadata ⇒ ::Google::Cloud::Dialogflow::CX::V3::FlowTraceMetadata
Metadata of the flow trace.
-
#input_parameters ⇒ ::Google::Protobuf::Struct
Optional.
-
#output_parameters ⇒ ::Google::Protobuf::Struct
Optional.
-
#playbook_trace_metadata ⇒ ::Google::Cloud::Dialogflow::CX::V3::PlaybookTraceMetadata
Metadata of the playbook trace.
-
#speech_processing_metadata ⇒ ::Google::Cloud::Dialogflow::CX::V3::SpeechProcessingMetadata
Metadata of the speech-to-text and speech-to-text processing.
-
#start_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#actions ⇒ ::Array<::Google::Cloud::Dialogflow::CX::V3::Action>
Returns The actions performed by the agent and the user during this session.
60 61 62 63 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/trace.rb', line 60 class TraceBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#complete_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Timestamp of the end of the trace block.
60 61 62 63 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/trace.rb', line 60 class TraceBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#end_state ⇒ ::Google::Cloud::Dialogflow::CX::V3::OutputState (readonly)
Returns Optional. Output only. The end state of the trace block.
60 61 62 63 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/trace.rb', line 60 class TraceBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#flow_trace_metadata ⇒ ::Google::Cloud::Dialogflow::CX::V3::FlowTraceMetadata
Returns Metadata of the flow trace.
Note: The following fields are mutually exclusive: flow_trace_metadata, playbook_trace_metadata, speech_processing_metadata. If a field in that set is populated, all other fields in the set will automatically be cleared.
60 61 62 63 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/trace.rb', line 60 class TraceBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#input_parameters ⇒ ::Google::Protobuf::Struct
Returns Optional. A list of input parameters of the trace block.
60 61 62 63 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/trace.rb', line 60 class TraceBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#output_parameters ⇒ ::Google::Protobuf::Struct
Returns Optional. A list of output parameters of the trace block.
60 61 62 63 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/trace.rb', line 60 class TraceBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#playbook_trace_metadata ⇒ ::Google::Cloud::Dialogflow::CX::V3::PlaybookTraceMetadata
Returns Metadata of the playbook trace.
Note: The following fields are mutually exclusive: playbook_trace_metadata, flow_trace_metadata, speech_processing_metadata. If a field in that set is populated, all other fields in the set will automatically be cleared.
60 61 62 63 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/trace.rb', line 60 class TraceBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#speech_processing_metadata ⇒ ::Google::Cloud::Dialogflow::CX::V3::SpeechProcessingMetadata
Returns Metadata of the speech-to-text and speech-to-text processing.
Note: The following fields are mutually exclusive: speech_processing_metadata, playbook_trace_metadata, flow_trace_metadata. If a field in that set is populated, all other fields in the set will automatically be cleared.
60 61 62 63 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/trace.rb', line 60 class TraceBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#start_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Timestamp of the start of the trace block.
60 61 62 63 |
# File 'proto_docs/google/cloud/dialogflow/cx/v3/trace.rb', line 60 class TraceBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |